<?php

/**
 * Phire Content Browser
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

require_once '../bootstrap.php';
require_once '../core/process/session.check.php';

include_once '../core/process/init.php';
include_once '../core/includes/sub.header.php';

// Check for the proper system browser variables.
if (!isset($_GET['browser']) || !isset($_GET['type'])) {

    $asset = $lang->__('Asset Browser');
    $error = $lang->__('The correct system browser data was not passed.');
    print <<<TABLEHEADER
    <h3 class="blueHeader">{$asset}</h3>
    <table class="dataTableClass" style="margin-bottom: 25px;" cellpadding="0" cellspacing="0">
        <tr style="height: 25px;"><td class="grayHeader" style="height: 25px;">&nbsp;</td></tr>
        <tr><td style="padding: 25px;">{$error}</td></tr>
    </table>

TABLEHEADER;

// If proper system browser variables have been passed, render the system browser.
} else {

    // If the browser is set to CKEditor, set the function callbacks based on the browser type.
    if ($_GET['browser'] == 'ckeditor') {

        $scr = "    <script type=\"text/javascript\">var funcNum = getUrlParam('CKEditorFuncNum');</script>\n";
        $funcCall = ($_GET['type'] == 'file') ? "window.opener.CKEDITOR.tools.callFunction(funcNum, this.href.replace('http://', ''))" : "window.opener.CKEDITOR.tools.callFunction(funcNum, this.href)";

    // Else, if the browser is set to TinyMCE, set the function callbacks based on the browser type.
    } else if ($_GET['browser'] == 'tinymce') {

        $scr = <<<SCR
    <script type="text/javascript" src="../core/scripts/tinymce/jscripts/tiny_mce/tiny_mce_popup.js"></script>
    <script type="text/javascript">
        var FileBrowserDialogue = {
            mySubmit : function (val) {
                var URL = val;
                var win = tinyMCEPopup.getWindowArg("window");

                // insert information now
                win.document.getElementById(tinyMCEPopup.getWindowArg("input")).value = URL;

                // are we an image browser
                if (typeof(win.ImageDialog) != "undefined") {
                    // we are, so update image dimensions...
                    if (win.ImageDialog.getImageData)
                        win.ImageDialog.getImageData();

                    // ... and preview if necessary
                    if (win.ImageDialog.showPreviewImage)
                        win.ImageDialog.showPreviewImage(URL);
                }
                // close popup window
                tinyMCEPopup.close();
            }
        }
        tinyMCEPopup.onInit.add(FileBrowserDialogue);
    </script>

SCR;

        $funcCall = "FileBrowserDialogue.mySubmit(this.href)";

    } else if ($_GET['browser'] == 'native') {

        $scr = null;
        $funcCall = "nativeBrowser(this.href, '{$_GET['type']}')";

    }

    // If the browser type is file, retrieve system files, image and page URLs for linking purposes.
    if ($_GET['type'] == 'file') {

        // Print the browser header.
        print("    <h3 class=\"blueHeader\">" . $lang->__('URL Browser') . "</h3>\n");
        print("    <h4 style=\"margin: 0 auto 10px auto; width: 95%; font-size: 0.9em;\">(" . $lang->__('Click to Select') . ")</h4>\n");
        print($scr);

        $sess = Moc10_Session::getInstance();

        foreach ($sess->sites as $sid) {

            $site = new Phire_Table_Sites();
            $site->findById($sid);

            $urls = new Phire_Table_Pages();
            $urls->findAll('page_title ASC', 'site_id', $sid);

            $files = new Phire_Table_Files();
            $files->findAll('file_name ASC', 'site_id', $sid);

            $images = new Phire_Table_Images();
            $images->findAll('image_name ASC', 'site_id', $sid);

            // Print the table header.
            print <<<TABLEHEADER
    <table class="dataTableClass" style="margin-bottom: 25px;" cellpadding="0" cellspacing="0">
        <tr style="height: 25px;"><td colspan="3" class="grayHeader" style="height: 25px;"><strong>{$site->site_domain}</strong></td></tr>

TABLEHEADER;

            // If page URLs are found, format and output them.
            if (isset($urls->rows[0])) {
                print("        <tr><td colspan=\"3\" style=\"background-color: #eee;\"><strong>" . $lang->__('URLs') . "</strong></td></tr>\n");
                foreach ($urls->rows as $url) {
                    print("        <tr><td style=\"width: 50%; padding: 8px 5px 8px 5px;\"><a href=\"http://{$site->site_domain}{$url->page_url}\" onclick=\"{$funcCall}; window.close(); return false;\">{$url->page_title}</a></td><td style=\"width: 40%; padding: 8px 5px 8px 5px;\">{$url->page_url}</td><td style=\"width: 10%; padding: 8px 5px 8px 5px;\">&nbsp;</td></tr>\n");
                }
            }

            // If files are found, format and output them.
            if (isset($files->rows[0])) {
                print("        <tr><td colspan=\"3\" style=\"background-color: #eee;\"><strong>" . $lang->__('Files') . "</strong></td></tr>\n");
                foreach ($files->rows as $file) {
                    print("        <tr><td style=\"width: 50%; padding: 8px 5px 8px 5px;\"><a href=\"http://{$site->site_domain}" . BASE_PATH . CONTENT_PATH . "/assets/files/{$file->file_name}\" onclick=\"{$funcCall}; window.close(); return false;\">{$file->file_name}</a></td><td style=\"width: 40%; padding: 8px 5px 8px 5px;\">{$file->file_title}</td><td style=\"width: 10%; padding: 8px 5px 8px 5px;\">&nbsp;</td></tr>\n");
                }
            }

            // If images are found, format and output them.
            if (isset($images->rows[0])) {
                print("        <tr><td colspan=\"3\" style=\"background-color: #eee;\"><strong>" . $lang->__('Images') . "</strong></td></tr>\n");
                foreach ($images->rows as $image) {
                    $imgLinksAry = array();
                    if (file_exists($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $image->image_name)) {
                        $imgLinksAry[] = "<a href=\"http://{$site->site_domain}" . BASE_PATH . CONTENT_PATH . "/assets/images/large/{$image->image_name}\" onclick=\"{$funcCall}; window.close(); return false;\">Large</a>";
                    }
                    if (file_exists($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $image->image_name)) {
                        $imgLinksAry[] = "<a href=\"http://{$site->site_domain}" . BASE_PATH . CONTENT_PATH . "/assets/images/medium/{$image->image_name}\" onclick=\"{$funcCall}; window.close(); return false;\">Medium</a>";
                    }
                    if (file_exists($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $image->image_name)) {
                        $imgLinksAry[] = "<a href=\"http://{$site->site_domain}" . BASE_PATH . CONTENT_PATH . "/assets/images/small/{$image->image_name}\" onclick=\"{$funcCall}; window.close(); return false;\">Small</a>";
                    }
                    print("        <tr><td style=\"width: 50%\"><strong>{$image->image_name}</strong> (" . implode(' | ', $imgLinksAry) . ")</td><td style=\"width: 40%\">{$image->image_title}</td><td style=\"width: 10%\"><img src=\"http://{$site->site_domain}" . BASE_PATH . CONTENT_PATH . "/assets/images/large/{$image->image_name}\" width=\"75%\" alt=\"{$image->image_name}\" /></td></tr>\n");
                }
            }

            // Else, render a 'none found' message.
            if (!isset($urls->rows[0]) && !isset($files->rows[0]) && !isset($images->rows[0])) {
                print("        <tr><td colspan=\"3\" style=\"padding: 25px;\">" . $lang->__('There are currently no assets.') . "</td></tr>\n");
            }

            // Print the table footer.
            print("    </table>\n");

        }

    // Else, if the browser type is image, retrieve system images for placement purposes.
    } else if ($_GET['type'] == 'image') {

        // Print the browser header.
        print("    <h3 class=\"blueHeader\">" . $lang->__('Image Browser') . "</h3>\n");
        print("    <h4 style=\"margin: 0 auto 10px auto; width: 95%; font-size: 0.9em;\">(" . $lang->__('Click to Select') . ")</h4>\n");
        print($scr);

        $sess = Moc10_Session::getInstance();

        foreach ($sess->sites as $sid) {

            $site = new Phire_Table_Sites();
            $site->findById($sid);

            $files = new Phire_Table_Files();
            $files->execute("SELECT * FROM " . DB_PREFIX . "files WHERE (file_name LIKE '%jpg' OR file_name LIKE '%gif' OR file_name LIKE '%png') AND site_id = '" . $sid . "'");

            $images = new Phire_Table_Images();
            $images->findAll('image_name ASC', 'site_id', $sid);

            // Print the table header.
            print <<<TABLEHEADER
    <table class="dataTableClass" style="margin-bottom: 25px;" cellpadding="0" cellspacing="0">
        <tr style="height: 25px;"><td colspan="3" class="grayHeader" style="height: 25px;"><strong>{$site->site_domain}</strong></td></tr>

TABLEHEADER;

            // If images are found, format and output them.
            if (isset($images->rows[0])) {
                print("        <tr><td colspan=\"3\" style=\"background-color: #eee;\"><strong>" . $lang->__('Images') . "</strong></td></tr>\n");
                foreach ($images->rows as $image) {
                    $imgLinksAry = array();
                    if (file_exists($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $image->image_name)) {
                        $imgLinksAry[] = "<a href=\"http://{$site->site_domain}" . BASE_PATH . CONTENT_PATH . "/assets/images/large/{$image->image_name}\" onclick=\"{$funcCall}; window.close(); return false;\">Large</a>";
                    }
                    if (file_exists($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $image->image_name)) {
                        $imgLinksAry[] = "<a href=\"http://{$site->site_domain}" . BASE_PATH . CONTENT_PATH . "/assets/images/medium/{$image->image_name}\" onclick=\"{$funcCall}; window.close(); return false;\">Medium</a>";
                    }
                    if (file_exists($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $image->image_name)) {
                        $imgLinksAry[] = "<a href=\"http://{$site->site_domain}" . BASE_PATH . CONTENT_PATH . "/assets/images/small/{$image->image_name}\" onclick=\"{$funcCall}; window.close(); return false;\">Small</a>";
                    }
                    print("        <tr><td style=\"width: 50%\"><strong>{$image->image_name}</strong> (" . implode(' | ', $imgLinksAry) . ")</td><td style=\"width: 40%\">{$image->image_title}</td><td style=\"width: 10%\"><img src=\"http://{$site->site_domain}" . BASE_PATH . CONTENT_PATH . "/assets/images/large/{$image->image_name}\" width=\"75%\" alt=\"{$image->image_name}\" /></td></tr>\n");
                }
            // Else, render a 'none found' message.
            } else {
                print("        <tr><td colspan=\"3\" style=\"padding: 25px;\">" . $lang->__('There are currently no images.') . "</td></tr>\n");
            }

            // If images are found within the files, format and output them.
            if (isset($files->rows[0])) {
                print("        <tr><td colspan=\"3\" style=\"background-color: #eee;\"><strong>" . $lang->__('Files') . "</strong></td></tr>\n");
                foreach ($files->rows as $file) {
                    print("        <tr><td style=\"width: 50%\"><a href=\"http://{$site->site_domain}" . BASE_PATH . CONTENT_PATH . "/assets/files/{$file->file_name}\" onclick=\"{$funcCall}; window.close(); return false;\">{$file->file_name}</a></td><td style=\"width: 40%\">{$file->file_title}</td><td style=\"width: 10%\"><img src=\"http://{$site->site_domain}" . BASE_PATH . CONTENT_PATH . "/assets/files/{$file->file_name}\" width=\"75%\" alt=\"{$file->file_name}\" /></td></tr>\n");
                }
            // Else, render a 'none found' message.
            } else {
                print("        <tr><td colspan=\"3\" style=\"padding: 25px;\">" . $lang->__('There are currently no images within the files.') . "</td></tr>\n");
            }

            // Print the table footer.
            print("    </table>\n");

        }

    // Else, declare that no assets were found.
    } else {

        $asset = $lang->__('Asset Browser');
        $error = $lang->__('No assets were found.');

        print <<<TABLEHEADER
    <h3 class="blueHeader">{$asset}</h3>
    <table class="dataTableClass" style="margin-bottom: 25px;" cellpadding="0" cellspacing="0">
        <tr style="height: 25px;"><td class="grayHeader" style="height: 25px;">&nbsp;</td></tr>
        <tr><td style="padding: 25px;">{$error}</td></tr>
    </table>

TABLEHEADER;

    }

}

include_once '../core/includes/sub.footer.php';

?>