<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Comments
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Comments
 *
 * @category   Phire
 * @package    Phire_Comments
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Comments
{

    /**
     * Page content
     * @var string
     */
    protected $_content = null;

    /**
     * Page object
     * @var Phire_Table_Pages
     */
    protected $_page_object = null;

    /**
     * Preserve flag
     * @var boolean
     */
    protected $_preserve = false;

    /**
     * Constructor
     *
     * Instantiate the comment object.
     *
     * @param  string $content
     * @param  Phire_Table_Pages $page_obj
     * @param  boolean $preserve
     * @return void
     */
    public function __construct($content, $page_obj, $preserve)
    {

        $this->_content = $content;
        $this->_page_object = $page_obj;
        $this->_preserve = $preserve;

    }

    /**
     * Static method to instantiate the comment object and
     * return itself to facilitate chaining methods together.
     *
     * @param  string $cont
     * @param  Phire_Table_Pages $page_obj
     * @param  boolean $pre
     * @return Phire_Comment
     */
    public static function init($cont, $po, $pre)
    {

        return new self($cont, $po, $pre);

    }

    /**
     * Method to process comments.
     *
     * @return string
     */
    public function process()
    {

        $page_content = $this->_content;
        $lang = new Phire_Language();
        $sess = Moc10_Session::getInstance();
        $pg = (isset($_GET['page'])) ? $_GET['page'] : 1;

        // If comments are allowed, process comments and/or comment form.
        if (($this->_page_object->comments_allowed == 'Yes') && ($this->_page_object->comment_allow == 'Yes')) {

            if ($this->_preserve) {

                $page_content .= "\n[{comments}]";

            } else {

                $user_id = (isset($sess->user_id)) ? $sess->user_id : 0;
                $member_id = (isset($sess->member_id)) ? $sess->member_id : 0;

                $form = new Phire_Form_AddComment(BASE_PATH . $this->_page_object->page_url, 'post', '        ');
                $page_content .= "\n        <div id=\"commentHeader\">" . $lang->__('Comments') . "</div>";

                // If the comment form has been submitted, validate and process.
                if (isset($_POST['cmt_submit'])) {
                    $cmt_auth = (isset($_POST['comment_author'])) ? $_POST['comment_author'] : null;
                    $cmt_cont = (isset($_POST['comment_content'])) ? $_POST['comment_content'] : null;
                    $cap = (isset($_POST['captcha_input'])) ? $_POST['captcha_input'] : null;
                    $hash = (isset($_POST['captcha'])) ? $_POST['captcha'] : null;
                    $form->init($cmt_auth, $cmt_cont, $cap, $hash, $_POST['page_id'], $_POST['user_id'], $_POST['member_id']);

                    if ($form->isValid()) {

                        $author = ($cmt_auth != '') ? $cmt_auth : $lang->__('Anonymous');

                        // Check comment against spam rules.
                        $spam = false;

                        if ($this->_page_object->spam_rules != '') {
                            $spamRules = str_replace(', ', ',', $this->_page_object->spam_rules);
                            $spamConds = explode(',', $spamRules);
                            foreach ($spamConds as $cond) {
                                if (stripos($author, $cond) !== false) {
                                    $spam = true;
                                } else if (stripos($cmt_cont, $cond) !== false) {
                                    $spam = true;
                                } else if (stripos($_SERVER['REMOTE_ADDR'], $cond) !== false) {
                                    $spam = true;
                                }
                            }
                        }

                        // Save new comment in the system.
                        $flds = array('page_id' => $_POST['page_id'],
                                      'user_id' => $_POST['user_id'],
                                      'member_id' => $_POST['member_id'],
                                      'comment_author' => $author,
                                      'comment_ip' => $_SERVER['REMOTE_ADDR'],
                                      'comment_content' => (string)Moc10_String::setString($cmt_cont)->striptags(),
                                      'comment_posted' => date('Y-m-d H:i:s'),
                                      'comment_approved' => (($this->_page_object->comment_approval == 'On') ? 'No' : 'Yes'),
                                      'comment_is_spam' => (($spam == true) ? 'Yes' : 'No'));

                        $cmt = new Phire_Table_Comments($flds);
                        $cmt->save();

                        // Return success message.
                        if ($cmt->comment_approved == 'No') {
                            $page_content .= "\n        <p>" . $lang->__('Thank you. Your comment has been posted to the site. It will be viewable once it has been approved.') . "</p>";
                        } else {
                            $page_content .= "\n        <p>" . $lang->__('Thank you. Your comment has been posted to the site.') . "</p>";
                        }

                        // Output the comment form again.
                        $form = new Phire_Form_AddComment(BASE_PATH . $this->_page_object->page_url, 'post', '        ');
                        $form->init(null, null, null, null, $this->_page_object->page_id, $user_id, $member_id);
                        $page_content .= "\n" . $form->render(true);

                    // Else, render the comment form with errors.
                    } else {
                        $page_content .= "\n" . $form->render(true);
                    }

                // Else, initialize and render the comment form.
                } else {

                    if (($this->_page_object->anon_comments == 'Yes') || ($member_id != 0) ) {
                        $form->init(null, null, null, null, $this->_page_object->page_id, $user_id, $member_id);
                        $page_content .= "\n" . $form->render(true);
                    } else {
                        $page_content .= "\n        <p>" . $lang->__('You must %1login%2 or %3register%4 to post comments.', array("<a href=\"/member/login\">", "</a>", "<a href=\"/member/register\">", "</a>")) . "</p>";
                    }

                }

                // Get comments and render on the page.
                $cmts = new Phire_Table_Comments();
                $cmts->execute("SELECT * FROM " . DB_PREFIX . "comments WHERE page_id = '" .$this->_page_object->page_id . "' AND comment_approved = 'Yes' AND comment_is_spam = 'No' ORDER BY comment_posted DESC");

                if (isset($cmts->rows[0])) {
                    $cmt_count = (count($cmts->rows) == 1) ? $lang->__('There is currently 1 comment on this page.') : $lang->__('There are currently %1 comments on this page.', count($cmts->rows));
                    $cmtHeader = "        <div id=\"commentFooter\"><span style=\"float: right;\">[{page_links}]</span><a name=\"comments\"></a>{$cmt_count}</div>";
                    $cmtTmpl = "\n        <div class=\"comment\"><span class=\"commentDate\">[{comment_date}]</span><strong>[{comment_author}]</strong><br /><br />[{comment_content}]</div>";
                    $cmtFooter = "\n        <div id=\"commentPageFooter\"><span style=\"float: right;\">[{page_links}]</span></div>";

                    if (($this->_page_object->default_date_format != '') && ($this->_page_object->default_time_format != '')) {
                        $df = $this->_page_object->default_date_format . ' ' . $this->_page_object->default_time_format;
                    } else if ($this->_page_object->default_date_format != '') {
                        $df = $this->_page_object->default_date_format;
                    } else {
                        $df = 'm/d/y';
                    }
                    $cmtAry = array();
                    foreach($cmts->rows as $comment) {
                        $cmtAry[] = array('comment_date' => Moc10_String::setString($comment->comment_posted)->date($df),
                                          'comment_author' => $comment->comment_author,
                                          'comment_content' => Moc10_String::setString($comment->comment_content)->links()->br());

                    }

                    $pg_num = ($this->_page_object->site_pagination_limit != 0) ? $this->_page_object->site_pagination_limit : count($cmtAry);
                    $pg_range = ($this->_page_object->site_pagination_range != 0) ? $this->_page_object->site_pagination_range : null;

                    // Render the page results.
                    $sess->comments = new Moc10_Session_Paginator($cmtAry, $pg_num, $pg_range);
                    $sess->comments->setHeader($cmtHeader);
                    $sess->comments->setRowTemplate($cmtTmpl);
                    $sess->comments->setFooter($cmtFooter);

                    $cmt_content = $sess->comments->render($pg, ' | ', 'subLinkOn', 'subLinkOff', null, true);
                    if (strpos($cmt_content, '/index.php') !== false) {
                        $query_string = substr($cmt_content, strpos($cmt_content, '&query='), (7 + strlen($this->_page_object->page_url)));
                        $cmt_content = str_replace('/index.php', $this->_page_object->page_url, $cmt_content);
                        $cmt_content = str_replace($query_string, '', $cmt_content);
                    }
                    $page_content .= $cmt_content;

                } else {
                    $page_content .= "        <div id=\"commentFooter\"><a name=\"comments\"></a>" . $lang->__('There are currently no comments on this page.') . "</div>";
                }

            }

        }

        return $page_content;

    }

}
