<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_Site
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_Site extends Moc10_Form
{
    /**
     * Site object
     * @var Phire_Table_Sites
     */
    public $site = null;

    /**
     * Form template
     * @var string
     */
    protected $_template = null;

    /**
     * $_POST fields
     * @var array
     */
    protected $_postFields = array('plugin' => null,
                                   'site_domain' => null,
                                   'site_docroot' => null,
                                   'site_email' => null,
                                   'content_type' => null,
                                   'default_charset' => null,
                                   'default_title' => null,
                                   'default_author' => null,
                                   'default_keywords' => null,
                                   'default_desc' => null,
                                   'default_robots' => null,
                                   'default_template_id' => -1,
                                   'default_404' => '<p>404 - Page Not Found</p>',
                                   'default_date' => null,
                                   'default_time' => null,
                                   'title_separator' => null,
                                   'large_size' => null,
                                   'large_action' => null,
                                   'medium_size' => null,
                                   'medium_action' => null,
                                   'small_size' => null,
                                   'small_action' => null,
                                   'allowed_image_formats' => array('jpg', 'gif', 'png'),
                                   'image_max_size' => '25',
                                   'image_max_size_select' => 'MB',
                                   'allowed_file_formats' => array('any'),
                                   'allowed_archives_formats' => array(),
                                   'allowed_documents_formats' => array(),
                                   'allowed_graphics_formats' => array(),
                                   'allowed_media_formats' => array(),
                                   'allowed_web_formats' => array(),
                                   'file_max_size' => '25',
                                   'file_max_size_select' => 'MB',
                                   'allowed_content_types' => array('3001', '3002'),
                                   'member_allow' => 'No',
                                   'member_enable_login' => 'No',
                                   'member_enable_registration' => 'No',
                                   'member_registration' => 'Minimum',
                                   'member_personal' => null,
                                   'member_verification' => 'Off',
                                   'member_approval' => 'Off',
                                   'member_ssl_connection' => 'No',
                                   'member_password_encoding' => 'Off',
                                   'member_redirects' => '',
                                   'input_captcha' => 'Off',
                                   'anon_comments' => 'No',
                                   'comment_allow' => 'No',
                                   'comment_approval' => 'Off',
                                   'spam_rules' => null,
                                   'feed_type' => 'RSS',
                                   'feed_limit' => 0,
                                   'page_caching' => 'Off',
                                   'open_authoring' => 'On',
                                   'site_pagination_limit' => '25',
                                   'site_pagination_range' => '10',
                                   'use_ssl_connection' => 'No',
                                   'site_live' => 'No',
                                   'cur_domain' => null,
                                   'cont_edit' => null,
                                   'flush_stats' => 'No',
                                   'site_id' => 0);

    /**
     * Language object
     * @var Phire_Language
     */
    protected $_lang = null;

    /**
     * Initialization method for the site form.
     *
     * @param  array $post
     * @return void
     */
    public function init($post = null)
    {

        $this->_lang = new Phire_Language();

        $this->_setFields($post);
        $this->_setTemplates();

        $this->setAttributes('id', 'addSiteForm');
        $this->setAttributes('onsubmit', "return addSiteFrm.addValidate();");

        // Create the 'site_domain' form element.
        $site_domain = new Moc10_Form_Element('text', 'site_domain', $this->_postFields['site_domain']);
        $site_domain->setLabel($this->_lang->__('Site Domain:'));
        $site_domain->setAttributes('size', '120');
        $site_domain->setAttributes('style', 'width: 640px;');
        $site_domain->setAttributes('onkeyup', "xmlhttp.getRequest('../core/process/check.domain.php?current=" . $this->_postFields['site_domain'] . "&domain=' + this.value, checkDomain); return false;");
        $site_domain->setRequired(true);

        // If the form has been submitted, validate the site domain.
        if ((!is_null($this->_postFields['site_domain'])) && ($this->_postFields['site_domain'] != $this->_postFields['cur_domain'])) {
            $dupe_dom = new Phire_Table_Sites();
            $dupe_dom->findBy('site_domain', $this->_postFields['site_domain']);
            if (isset($dupe_dom->site_id)) {
                $site_domain->addValidator('NotEqual', true, $dupe_dom->site_domain, $this->_lang->__('That domain already exists in the system. Please try another domain.'));
            }
        }

        // Create the 'site_docroot' form element.
        $site_docroot = new Moc10_Form_Element('text', 'site_docroot', $this->_postFields['site_docroot']);
        $site_docroot->setLabel($this->_lang->__('Site Document Root:'));
        $site_docroot->setAttributes('size', '120');
        $site_docroot->setAttributes('style', 'width: 640px;');
        $site_docroot->setAttributes('onkeyup', "xmlhttp.getRequest('../core/process/check.docroot.php?site_id=" . $this->_postFields['site_id'] . "&docroot=' + this.value, checkDocroot); return false;");
        $site_docroot->setRequired(true);

        // If the form has been submitted, validate the site document root.
        if (!is_null($this->_postFields['site_docroot'])) {
            if (!file_exists($this->_postFields['site_docroot'])) {
                $site_docroot->addValidator('Equal', true, "Docroot doesn't exists", 'That document root does not exist. Please enter a document root that exists.');
            } else if (($this->_postFields['site_id'] != '2001') && ((!file_exists($this->_postFields['site_docroot'] . BASE_PATH . '/index.php')) || (!file_exists($this->_postFields['site_docroot'] . BASE_PATH . CONTENT_PATH . '/')))) {
                $site_docroot->addValidator('Equal', true, "Files don't exists", $this->_lang->__('The new site system files have not been installed in that document root.'));
            } else if ((!Phire_Dirs::writable($this->_postFields['site_docroot']))) {
                $site_docroot->addValidator('Equal', true, "Folders aren't writable", $this->_lang->__('The necessary new site system files are not writable.'));
            }
        }

        // Create the 'site_email' form element.
        $site_email = new Moc10_Form_Element('text', 'site_email', $this->_postFields['site_email']);
        $site_email->setLabel($this->_lang->__('Site Email:'));
        $site_email->setAttributes('size', '120');
        $site_email->setAttributes('style', 'width: 640px;');
        $site_email->addValidator('Email');

        // Get the content types.
        $content_types = new Phire_Table_ContentTypes();
        $content_types->findAll();

        $content_types_array = array();
        $allowed_types_array = array();
        foreach ($content_types->rows as $ctype) {
            $content_types_array[$ctype->type_id] = $ctype->type_name . ' (' . $ctype->type . ')';
            $allowed_types_array[$ctype->type_id] = $ctype->type_name;
        }

        // Create the 'content_type' form element.
        $content_type = new Moc10_Form_Element_Select('content_type', $content_types_array, $this->_postFields['content_type']);
        $content_type->setLabel($this->_lang->__('Default Content Type:'));
        $content_type->setAttributes('onchange', 'addSiteFrm.checkTypes(this.value);');

        // Get the character sets.
        $charsets = new Phire_Table_Charsets();
        $charsets->findAll();

        $charsets_array = array();
        foreach ($charsets->rows as $chrset) {
            $charsets_array[$chrset->charset_id] = $chrset->charset_name . ' (' . $chrset->charset . ')';
        }

        // Create the 'default_charset' form element.
        $default_charset = new Moc10_Form_Element_Select('default_charset', $charsets_array, $this->_postFields['default_charset']);
        $default_charset->setLabel($this->_lang->__('Default Character Set:'));

        // Create the 'default_title' form element.
        $default_title = new Moc10_Form_Element('text', 'default_title', $this->_postFields['default_title']);
        $default_title->setLabel($this->_lang->__('Default Title:'));
        $default_title->setAttributes('size', '120');
        $default_title->setAttributes('style', 'width: 640px;');

        // Create the 'title_separator' form element.
        $title_separator = new Moc10_Form_Element('text', 'title_separator', $this->_postFields['title_separator']);
        $title_separator->setLabel($this->_lang->__('Title Separator:'));
        $title_separator->setAttributes('size', '15');

        // Create the 'default_author' form element.
        $default_author = new Moc10_Form_Element('text', 'default_author', $this->_postFields['default_author']);
        $default_author->setLabel($this->_lang->__('Default Author:'));
        $default_author->setAttributes('size', '120');
        $default_author->setAttributes('style', 'width: 640px;');

        // Create the 'default_keywords' form element.
        $default_keywords = new Moc10_Form_Element('text', 'default_keywords', $this->_postFields['default_keywords']);
        $default_keywords->setLabel($this->_lang->__('Default Keywords:'));
        $default_keywords->setAttributes('size', '150');
        $default_keywords->setAttributes('style', 'width: 800px;');

        // Create the 'default_desc' form element.
        $default_desc = new Moc10_Form_Element('text', 'default_desc', $this->_postFields['default_desc']);
        $default_desc->setLabel($this->_lang->__('Default Description:'));
        $default_desc->setAttributes('size', '150');
        $default_desc->setAttributes('style', 'width: 800px;');

        // Get the templates.
        $tmpls = new Phire_Table_Templates();
        $tmpls->findAll('template_id ASC', 'site_id', $this->_postFields['site_id']);

        $tmpls_array = array('-1' => '(' . $this->_lang->__('None') . ')', '0' => '(' . $this->_lang->__('System Default') . ')');
        foreach ($tmpls->rows as $tmpl) {
            $tmpls_array[$tmpl->template_id] = $tmpl->template_name;
        }

        // Create the 'default_template_id' form element.
        $default_template_id = new Moc10_Form_Element_Select('default_template_id', $tmpls_array, $this->_postFields['default_template_id']);
        $default_template_id->setLabel($this->_lang->__('Default Template:'));

        // Create the 'default_404' form element.
        $default_404 = new Moc10_Form_Element_Textarea('default_404', $this->_postFields['default_404']);
        $default_404->setLabel($this->_lang->__('Default 404 Message:'));
        $default_404->setAttributes('rows', '5');
        $default_404->setAttributes('cols', '150');
        $default_404->setAttributes('spellcheck', 'false');
        $default_404->setAttributes('wrap', 'off');
        $default_404->setAttributes('style', 'width: 800px;');
        $default_404->setRequired(true);

        // Create the 'default_date' form element.
        $default_date = new Moc10_Form_Element_Select('default_date', array('M j Y' => 'Jan 4 ' . date('Y'), 'F j, Y' => 'January 4, ' . date('Y'), 'm/d/Y' => '01/04/' . date('Y'), 'm/d/y' => '01/04/10', 'D, M j Y' => 'Mon, Jan 4 ' . date('Y'), 'l, F j, Y' => 'Monday, January 4, ' . date('Y'), 'l, m/d/Y' => 'Monday, 1/4/' . date('Y'), 'D, m/d/y' => 'Mon, 1/4/10'), $this->_postFields['default_date']);
        $default_date->setLabel($this->_lang->__('Default Date/Time Format:'));
        $default_date->setRequired(true);

        // Create the 'default_time' form element.
        $default_time = new Moc10_Form_Element_Select('default_time', array('--' => '(' . $this->_lang->__('Do not include time') . ')', 'g:i A' => 'HH:MM (AM/PM)', 'H:i' => 'HH:MM (' . $this->_lang->__('24 Hour') . ')'), $this->_postFields['default_time']);
        $default_time->setLabel($this->_lang->__('Default Time Format:'));

        // Get robots.
        $robots = new Phire_Table_Robots();
        $robots->findAll();

        $robots_array = array();
        foreach ($robots->rows as $robot) {
            $robots_array[$robot->robot_id] = $robot->robots;
        }

        // Create the 'default_robots' form element.
        $default_robots = new Moc10_Form_Element_Select('default_robots', $robots_array, $this->_postFields['default_robots']);
        $default_robots->setLabel($this->_lang->__('Default Robots:'));

        // Create the 'large_action' form element.
        $large_action = new Moc10_Form_Element_Select('large_action', array('None' => $this->_lang->__('None'), 'Crop' => $this->_lang->__('Crop'), 'Resize' => $this->_lang->__('Resize'), 'Scale' => $this->_lang->__('Scale')), $this->_postFields['large_action']);
        $large_action->setLabel($this->_lang->__('Large Images:'));
        $large_action->setAttributes('onchange', "setSize('large', this.value);");

        // Create the 'large_size' form element.
        $large_size = new Moc10_Form_Element('text', 'large_size', $this->_postFields['large_size']);
        $large_size->setAttributes('size', '5');

        // Create the 'medium_action' form element.
        $medium_action = new Moc10_Form_Element_Select('medium_action', array('None' => $this->_lang->__('None'), 'Crop' => $this->_lang->__('Crop'), 'Resize' => $this->_lang->__('Resize'), 'Scale' => $this->_lang->__('Scale')), $this->_postFields['medium_action']);
        $medium_action->setLabel($this->_lang->__('Medium Images:'));
        $medium_action->setAttributes('onchange', "setSize('medium', this.value);");

        // Create the 'medium_size' form element.
        $medium_size = new Moc10_Form_Element('text', 'medium_size', $this->_postFields['medium_size']);
        $medium_size->setAttributes('size', '5');

        // Create the 'small_action' form element.
        $small_action = new Moc10_Form_Element_Select('small_action', array('None' => $this->_lang->__('None'), 'Crop' => $this->_lang->__('Crop'), 'Resize' => $this->_lang->__('Resize'), 'Scale' => $this->_lang->__('Scale')), $this->_postFields['small_action']);
        $small_action->setLabel($this->_lang->__('Small Images:'));
        $small_action->setAttributes('onchange', "setSize('small', this.value);");

        // Create the 'small_size' form element.
        $small_size = new Moc10_Form_Element('text', 'small_size', $this->_postFields['small_size']);
        $small_size->setAttributes('size', '5');

        // Create the 'allowed_image_formats' form element.
        $allowed_image_formats = new Moc10_Form_Element_Checkbox('allowed_image_formats', array('jpg' => 'jpg', 'gif' => 'gif', 'png' => 'png'), $this->_postFields['allowed_image_formats']);
        $allowed_image_formats->setLabel($this->_lang->__('Allowed Image Formats:'));
        $allowed_image_formats->setRequired(true);

        // Create the 'allowed_file_formats' form element.
        $allowed_file_formats = new Moc10_Form_Element_Checkbox('allowed_file_formats', array('any' => 'Any'), $this->_postFields['allowed_file_formats']);
        $allowed_file_formats->setLabel($this->_lang->__('Allowed File Formats:'));

        // Create the 'allowed_archives_formats' form element.
        $allowed_archives_formats = new Moc10_Form_Element_Checkbox('allowed_archives_formats', array('gz' => 'gz', 'sit' => 'sit', 'tar' => 'tar', 'zip' => 'zip'), $this->_postFields['allowed_archives_formats']);
        $allowed_archives_formats->setLabel('<strong>' . $this->_lang->__('Archives:') . '</strong>');

        // Create the 'allowed_documents_formats' form element.
        $allowed_documents_formats = new Moc10_Form_Element_Checkbox('allowed_documents_formats', array('csv' => 'csv', 'doc|docx' => 'doc, docx', 'pdf' => 'pdf', 'ppt|pptx' => 'ppt, pptx', 'tsv' => 'tsv', 'txt' => 'txt', 'xls|xlsx' => 'xls, xlsx'), $this->_postFields['allowed_documents_formats']);
        $allowed_documents_formats->setLabel('<strong>' . $this->_lang->__('Documents:') . '</strong>');

        // Create the 'allowed_graphics_formats' form element.
        $allowed_graphics_formats = new Moc10_Form_Element_Checkbox('allowed_graphics_formats', array('ai' => 'ai', 'bmp' => 'bmp', 'eps' => 'eps', 'gif' => 'gif', 'jpg|jpe|jpeg' => 'jpg, jpe, jpeg', 'png' => 'png', 'psd' => 'psd', 'tif|tiff' => 'tif, tiff'), $this->_postFields['allowed_graphics_formats']);
        $allowed_graphics_formats->setLabel('<strong>' . $this->_lang->__('Graphics:') . '</strong>');

        // Create the 'allowed_media_formats' form element.
        $allowed_media_formats = new Moc10_Form_Element_Checkbox('allowed_media_formats', array('aif|aiff' => 'aif, aiff', 'avi' => 'avi', 'fla' => 'fla', 'flv' => 'flv', 'mov' => 'mov', 'mp2' => 'mp2', 'mp3' => 'mp3', 'mp4' => 'mp4', 'mpg|mpeg' => 'mpg, mpeg', 'swf' => 'swf', 'wav' => 'wav', 'wma' => 'wma', 'wmv' => 'wmv'), $this->_postFields['allowed_media_formats']);
        $allowed_media_formats->setLabel('<strong>' . $this->_lang->__('Media:') . '</strong>');

        // Create the 'allowed_web_formats' form element.
        $allowed_web_formats = new Moc10_Form_Element_Checkbox('allowed_web_formats', array('css' => 'css', 'html|htm|xhtml' => 'html, htm, xhtml', 'js' => 'js', 'php' => 'php', 'sql' => 'sql', 'xml' => 'xml'), $this->_postFields['allowed_web_formats']);
        $allowed_web_formats->setLabel('<strong>' . $this->_lang->__('Web:') . '</strong>');

        if (!isset($this->_postFields['allowed_file_formats'][0]) && !isset($this->_postFields['allowed_archives_formats'][0]) && !isset($this->_postFields['allowed_documents_formats'][0]) && !isset($this->_postFields['allowed_graphics_formats'][0]) && !isset($this->_postFields['allowed_media_formats'][0]) && !isset($this->_postFields['allowed_web_formats'][0])) {
            $allowed_file_formats->addValidator('NotEmpty');
        }

        // Create the 'image_max_size' form element.
        $image_max_size = new Moc10_Form_Element('text', 'image_max_size', $this->_postFields['image_max_size']);
        $image_max_size->setAttributes('size', '5');
        $image_max_size->addValidator('Num');
        $image_max_size->setLabel($this->_lang->__('Max Image Size:'));
        $image_max_size->setRequired(true);

        // Create the 'file_max_size_select' form element.
        $image_max_size_select = new Moc10_Form_Element_Select('image_max_size_select', array('MB' => 'MB', 'KB' => 'KB'), $this->_postFields['image_max_size_select']);

        // Create the 'file_max_size' form element.
        $file_max_size = new Moc10_Form_Element('text', 'file_max_size', $this->_postFields['file_max_size']);
        $file_max_size->setAttributes('size', '5');
        $file_max_size->addValidator('Num');
        $file_max_size->setLabel($this->_lang->__('Max File Size:'));
        $file_max_size->setRequired(true);

        // Create the 'file_max_size_select' form element.
        $file_max_size_select = new Moc10_Form_Element_Select('file_max_size_select', array('MB' => 'MB', 'KB' => 'KB'), $this->_postFields['file_max_size_select']);

        // Create the 'allowed_content_types' form element.
        $allowed_content_types = new Moc10_Form_Element_Checkbox('allowed_content_types', $allowed_types_array, $this->_postFields['allowed_content_types']);
        $allowed_content_types->setLabel($this->_lang->__('Allowed Content Types:'));
        $allowed_content_types->setRequired(true);

        // Create the 'member_allow' form element.
        $member_allow = new Moc10_Form_Element_Radio('member_allow', array('Yes' => $this->_lang->__('Yes'), 'No' => $this->_lang->__('No')), $this->_postFields['member_allow']);
        $member_allow->setLabel($this->_lang->__('Allow Members:'));

        // Create the 'member_enable_login' form element.
        $member_enable_login = new Moc10_Form_Element_Radio('member_enable_login', array('Yes' => $this->_lang->__('Yes'), 'No' => $this->_lang->__('No')), $this->_postFields['member_enable_login']);
        $member_enable_login->setLabel($this->_lang->__('Allow Login:'));

        // Create the 'member_enable_registration' form element.
        $member_enable_registration = new Moc10_Form_Element_Radio('member_enable_registration', array('Yes' => $this->_lang->__('Yes'), 'No' => $this->_lang->__('No')), $this->_postFields['member_enable_registration']);
        $member_enable_registration->setLabel($this->_lang->__('Allow Register:'));

        // Create the 'member_registration' form element.
        $member_registration = new Moc10_Form_Element_Select('member_registration', array('Minimum' => $this->_lang->__('Minimum'), 'Basic' => $this->_lang->__('Basic'), 'US' => $this->_lang->__('United States'), 'Intl' => $this->_lang->__('International')), $this->_postFields['member_registration']);
        $member_registration->setLabel($this->_lang->__('Registration:'));

        // Create the 'member_personal' form element.
        $member_personal = new Moc10_Form_Element_Checkbox('member_personal', array('Business' => $this->_lang->__('Collect Business?'), 'Personal' => $this->_lang->__('Collect Personal?'), 'Account' => $this->_lang->__('Create Account?')), $this->_postFields['member_personal']);

        // Create the 'member_verification' form element.
        $member_verification = new Moc10_Form_Element_Radio('member_verification', array('Off' => $this->_lang->__('Off'), 'On' => $this->_lang->__('On')), $this->_postFields['member_verification']);
        $member_verification->setLabel($this->_lang->__('Member Verification:'));

        // Create the 'member_approval' form element.
        $member_approval = new Moc10_Form_Element_Radio('member_approval', array('Off' => $this->_lang->__('Off'), 'On' => $this->_lang->__('On')), $this->_postFields['member_approval']);
        $member_approval->setLabel($this->_lang->__('Member Approval:'));

        // Create the 'member_ssl_connection' form element.
        $member_ssl_connection = new Moc10_Form_Element_Radio('member_ssl_connection', array('Yes' => $this->_lang->__('Yes'), 'No' => $this->_lang->__('No')), $this->_postFields['member_ssl_connection']);
        $member_ssl_connection->setLabel($this->_lang->__('SSL for Members:'));

        // Create the 'member_password_encoding' form element.
        $member_password_encoding = new Moc10_Form_Element_Radio('member_password_encoding', array('Off' => $this->_lang->__('Off'), 'On' => $this->_lang->__('On')), $this->_postFields['member_password_encoding']);
        $member_password_encoding->setLabel($this->_lang->__('Password Encoding:'));

        // Create the 'input_captcha' form element.
        $input_captcha = new Moc10_Form_Element_Radio('input_captcha', array('Off' => $this->_lang->__('Off'), 'On' => $this->_lang->__('On')), $this->_postFields['input_captcha']);
        $input_captcha->setLabel('CAPTCHA:');

        $member_redirects = explode('|', $this->_postFields['member_redirects']);

        // Create the 'verify_redirect' form element.
        $verify_redirect = new Moc10_Form_Element('text', 'verify_redirect', ((isset($member_redirects[0])) ? $member_redirects[0] : null));
        $verify_redirect->setLabel($this->_lang->__('Verify:'));
        $verify_redirect->setAttributes('size', '30');

        // Create the 'login_redirect' form element.
        $login_redirect = new Moc10_Form_Element('text', 'login_redirect', ((isset($member_redirects[1])) ? $member_redirects[1] : null));
        $login_redirect->setLabel($this->_lang->__('Login:'));
        $login_redirect->setAttributes('size', '30');

        // Create the 'logout_redirect' form element.
        $logout_redirect = new Moc10_Form_Element('text', 'logout_redirect', ((isset($member_redirects[2])) ? $member_redirects[2] : null));
        $logout_redirect->setLabel($this->_lang->__('Log Out:'));
        $logout_redirect->setAttributes('size', '30');

        // Create the 'forgot_redirect' form element.
        $forgot_redirect = new Moc10_Form_Element('text', 'forgot_redirect', ((isset($member_redirects[3])) ? $member_redirects[3] : null));
        $forgot_redirect->setLabel($this->_lang->__('Forgot:'));
        $forgot_redirect->setAttributes('size', '30');

        // Create the 'register_redirect' form element.
        $register_redirect = new Moc10_Form_Element('text', 'register_redirect', ((isset($member_redirects[4])) ? $member_redirects[4] : null));
        $register_redirect->setLabel($this->_lang->__('Register:'));
        $register_redirect->setAttributes('size', '30');

        // Create the 'profile_redirect' form element.
        $profile_redirect = new Moc10_Form_Element('text', 'profile_redirect', ((isset($member_redirects[5])) ? $member_redirects[5] : null));
        $profile_redirect->setLabel($this->_lang->__('Profile:'));
        $profile_redirect->setAttributes('size', '30');

        // Create the 'delete_redirect' form element.
        $delete_redirect = new Moc10_Form_Element('text', 'delete_redirect', ((isset($member_redirects[6])) ? $member_redirects[6] : null));
        $delete_redirect->setLabel($this->_lang->__('Delete:'));
        $delete_redirect->setAttributes('size', '30');

        // Create the 'anon_comments' form element.
        $anon_comments = new Moc10_Form_Element_Radio('anon_comments', array('Yes' => $this->_lang->__('Yes'), 'No' => $this->_lang->__('No')), $this->_postFields['anon_comments']);
        $anon_comments->setLabel($this->_lang->__('Anonymous?'));

        // Create the 'comment_allow' form element.
        $comment_allow = new Moc10_Form_Element_Radio('comment_allow', array('Yes' => $this->_lang->__('Yes'), 'No' => $this->_lang->__('No')), $this->_postFields['comment_allow']);
        $comment_allow->setLabel($this->_lang->__('Allow Comments:'));

        // Create the 'comment_approval' form element.
        $comment_approval = new Moc10_Form_Element_Radio('comment_approval', array('Off' => $this->_lang->__('Off'), 'On' => $this->_lang->__('On')), $this->_postFields['comment_approval']);
        $comment_approval->setLabel($this->_lang->__('Comment Approval:'));

        // Create the 'spam_rules' form element.
        $spam_rules = new Moc10_Form_Element_Textarea('spam_rules', $this->_postFields['spam_rules']);
        $spam_rules->setLabel($this->_lang->__('Spam Rules:'));
        $spam_rules->setAttributes('rows', '4');
        $spam_rules->setAttributes('cols', '120');
        $spam_rules->setAttributes('spellcheck', 'false');
        $spam_rules->setAttributes('wrap', 'off');
        $spam_rules->setAttributes('style', 'width: 680px;');

        // Create the 'feed_type' form element.
        $feed_type = new Moc10_Form_Element_Select('feed_type', array('RSS' => 'RSS', 'Atom' => 'Atom'), $this->_postFields['feed_type']);
        $feed_type->setLabel($this->_lang->__('Feed Type:'));

        // Create the 'feed_limit' form element.
        $feed_limit = new Moc10_Form_Element('text', 'feed_limit', $this->_postFields['feed_limit']);
        $feed_limit->setAttributes('size', '5');
        $feed_limit->setLabel($this->_lang->__('Feed Limit:'));

        // Create the 'page_caching' form element.
        $page_caching = new Moc10_Form_Element_Radio('page_caching', array('Off' => $this->_lang->__('Off'), 'On' => $this->_lang->__('On')), $this->_postFields['page_caching']);
        $page_caching->setLabel($this->_lang->__('Page Caching:'));

        // Create the 'open_authoring' form element.
        $open_authoring = new Moc10_Form_Element_Radio('open_authoring', array('Off' => $this->_lang->__('Off'), 'On' => $this->_lang->__('On')), $this->_postFields['open_authoring']);
        $open_authoring->setLabel($this->_lang->__('Open Authoring:'));

        // Create the 'site_pagination_limit' form element.
        $site_pagination_limit = new Moc10_Form_Element('text', 'site_pagination_limit', $this->_postFields['site_pagination_limit']);
        $site_pagination_limit->setAttributes('size', '5');
        $site_pagination_limit->setLabel($this->_lang->__('Pagination:'));

        // Create the 'site_pagination_range' form element.
        $site_pagination_range = new Moc10_Form_Element('text', 'site_pagination_range', $this->_postFields['site_pagination_range']);
        $site_pagination_range->setAttributes('size', '5');

        // Create the 'use_ssl_connection' form element.
        $use_ssl_connection = new Moc10_Form_Element_Radio('use_ssl_connection', array('Yes' => $this->_lang->__('Yes'), 'No' => $this->_lang->__('No')), $this->_postFields['use_ssl_connection']);
        $use_ssl_connection->setLabel($this->_lang->__('SSL Connection:'));

        // Create the 'flush_stats' form element.
        $flush_stats = new Moc10_Form_Element_Radio('flush_stats', array('Yes' => $this->_lang->__('Yes'), 'No' => $this->_lang->__('No')), $this->_postFields['flush_stats']);
        $flush_stats->setLabel($this->_lang->__('Flush Site Stats:'));

        // Create the 'site_live' form element.
        $site_live = new Moc10_Form_Element_Radio('site_live', array('Yes' => $this->_lang->__('Yes'), 'No' => $this->_lang->__('No')), $this->_postFields['site_live']);
        $site_live->setLabel($this->_lang->__('Site Live:'));
        $site_live->setRequired(true);

        // Create the 'cur_domain' form element.
        $cur_domain = new Moc10_Form_Element('hidden', 'cur_domain', $this->_postFields['cur_domain']);

        // Create the 'site_id' form element.
        $site_id = new Moc10_Form_Element('hidden', 'site_id', $this->_postFields['site_id']);

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $this->_lang->__('SAVE'));
        $submit->setAttributes('class', 'submitBtn');
        $submit->setAttributes('style', 'float: left;');

        // Set the form template and add the form element objects to the form.
        $this->setTemplate($this->_template);
        $this->addElements(array($site_domain, $site_docroot, $site_email, $content_type, $default_charset, $default_title, $default_author, $default_keywords, $default_desc, $default_template_id, $default_404, $default_date, $default_time, $default_robots, $title_separator, $large_action, $large_size, $medium_action, $medium_size, $small_action, $small_size, $allowed_image_formats, $image_max_size, $image_max_size_select, $allowed_file_formats, $allowed_archives_formats, $allowed_documents_formats, $allowed_graphics_formats, $allowed_media_formats, $allowed_web_formats, $file_max_size, $file_max_size_select, $allowed_content_types, $member_registration, $member_personal, $member_allow, $member_enable_login, $member_enable_registration, $member_verification, $member_approval, $member_ssl_connection, $member_password_encoding, $input_captcha, $verify_redirect, $login_redirect, $logout_redirect, $forgot_redirect, $register_redirect, $profile_redirect, $delete_redirect, $anon_comments, $comment_allow, $comment_approval, $spam_rules, $feed_type, $feed_limit, $page_caching, $open_authoring, $flush_stats, $site_pagination_limit, $site_pagination_range, $use_ssl_connection, $site_live, $site_id, $cur_domain, $submit));

    }

    /**
     * Method to save the site data.
     *
     * @return void
     */
    public function saveData()
    {

        $sess = Moc10_Session::getInstance();

        // Retrieve server configuration settings and set new site data accordingly.
        $config = new Phire_Table_Config();

        if (($config->settings['server_os'] == 'Windows') && (stripos($config->settings['server_software'], 'apache') !== false) && (stripos($this->_postFields['site_docroot'], "\\") !== false)) {
            $this->_postFields['site_docroot'] = str_replace("\\", "/", $this->_postFields['site_docroot']);
        }

        $lg_sz = ($this->_postFields['large_action'] == 'None') ? 0 : $this->_postFields['large_size'];
        $md_sz = ($this->_postFields['medium_action'] == 'None') ? 0 : $this->_postFields['medium_size'];
        $sm_sz = ($this->_postFields['small_action'] == 'None') ? 0 : $this->_postFields['small_size'];

        $img_max_sz = (isset($this->_postFields['image_max_size']) ? $this->_postFields['image_max_size'] . ' ' . $this->_postFields['image_max_size_select'] : '10 MB');
        $fle_max_sz = (isset($this->_postFields['file_max_size']) ? $this->_postFields['file_max_size'] . ' ' . $this->_postFields['file_max_size_select'] : '10 MB');

        if (in_array('jpg', $this->_postFields['allowed_image_formats'])) {
            $this->_postFields['allowed_image_formats'][] = 'jpe';
            $this->_postFields['allowed_image_formats'][] = 'jpeg';
        }

        $formats = array();
        if (isset($this->_postFields['allowed_file_formats'][0]) && ($this->_postFields['allowed_file_formats'][0] == 'any')) {
            $formats[] = 'any';
        } else {
            if (count($this->_postFields['allowed_archives_formats']) > 0) {
                $formats[] = implode('|', $this->_postFields['allowed_archives_formats']);
            }
            if (count($this->_postFields['allowed_documents_formats']) > 0) {
                $formats[] = implode('|', $this->_postFields['allowed_documents_formats']);
            }
            if (count($this->_postFields['allowed_graphics_formats']) > 0) {
                $formats[] = implode('|', $this->_postFields['allowed_graphics_formats']);
            }
            if (count($this->_postFields['allowed_media_formats']) > 0) {
                $formats[] = implode('|', $this->_postFields['allowed_media_formats']);
            }
            if (count($this->_postFields['allowed_web_formats']) > 0) {
                $formats[] = implode('|', $this->_postFields['allowed_web_formats']);
            }
        }

        $this->_postFields['member_registration'] .= (count($this->_postFields['member_personal']) > 0) ? '+' . implode('+', $this->_postFields['member_personal']) : '';

        $site_page_limit = (is_numeric($this->_postFields['site_pagination_limit'])) ? round(abs($this->_postFields['site_pagination_limit'])) : '0';
        $site_page_range = (is_numeric($this->_postFields['site_pagination_range'])) ? round(abs($this->_postFields['site_pagination_range'])) : '0';

        $member_redirects = (isset($_POST['verify_redirect']) ? $_POST['verify_redirect'] : '') . '|' . (isset($_POST['login_redirect']) ? $_POST['login_redirect'] : '') . '|' . (isset($_POST['logout_redirect']) ? $_POST['logout_redirect'] : '') . '|' . (isset($_POST['forgot_redirect']) ? $_POST['forgot_redirect'] : '') . '|' . (isset($_POST['register_redirect']) ? $_POST['register_redirect'] : '') . '|' . (isset($_POST['profile_redirect']) ? $_POST['profile_redirect'] : '') . '|' . (isset($_POST['delete_redirect']) ? $_POST['delete_redirect'] : '');

        // Edit existing site.
        if ($this->_postFields['site_id'] != 0) {

            // Get site and save new data.
            $this->site = new Phire_Table_Sites();
            $this->site->findById($this->_postFields['site_id']);

            if ($this->_postFields['flush_stats'] == 'Yes') {
                $pages = new Phire_Table_Pages();
                $pages->execute("UPDATE " . DB_PREFIX . "pages SET page_requests = 0 WHERE site_id = '" . $this->site->site_id . "'");
                $site404s = new Phire_Table_404s();
                $site404s->execute("DELETE FROM " . DB_PREFIX . "404s WHERE site_id = '" . $this->site->site_id . "'");
            }

            // If member password encoding is turned on, encode all of the members' passwords.
            if (($this->site->member_password_encoding == 'Off') && ($this->_postFields['member_password_encoding'] == 'On')) {
                $members = new Phire_Table_Members();
                $members->findAll(null, 'site_id', $this->site->site_id);
                foreach ($members->rows as $member) {
                    $mbr = new Phire_Table_Members();
                    $mbr->findById($member->member_id);
                    $mbr->password = sha1($mbr->password);
                    $mbr->save();
                }
            // Else, if member password encoding is on and switched off, reset member passwords and send email.
            } else if (($this->site->member_password_encoding == 'On') && ($this->_postFields['member_password_encoding'] == 'Off')) {
                $members = new Phire_Table_Members();
                $members->findAll(null, 'site_id', $this->site->site_id);

                // Build and send the notification email.
                $rcpts = array();
                $message = "[{name}],\n\n" . $this->_lang->__('Due to security measures enforced by the site admin, the password to your member account for %1 has been changed.', '[{site_domain}]') . " " . $this->_lang->__('Your new credentials for %1 are:', '[{site_domain}]') . "\n\n" . $this->_lang->__('Username:') . " [{username}]\n" . $this->_lang->__('Password:') . " [{password}]\n\n" . $this->_lang->__('You can log in at the link below and change your password or manage your account:') . "\n[{login_link}]\n\n" . $this->_lang->__('Thank You,') . "\n\n" . $this->_lang->__('The %1 Team', '[{site_domain}]') . "\n\n";

                foreach ($members->rows as $member) {
                    $mbr = new Phire_Table_Members();
                    $mbr->findById($member->member_id);
                    $mbr->password = strtolower(Moc10_String::setString('')->random(8));
                    $mbr->save();
                    if (($mbr->fname != '') && ($mbr->lname != '')) {
                        $name = $mbr->fname . " " . $mbr->lname;
                    } else if ($mbr->fname != '') {
                        $name = $mbr->fname;
                    } else {
                        $name = $mbr->email;
                    }

                    $rcpts[] = array('name' =>  $name,
                                     'email' => $mbr->email,
                                     'username' => $mbr->username,
                                     'password' => $mbr->password,
                                     'site_domain' => $this->site->site_domain,
                                     'login_link' => 'http://' . $this->site->site_domain . BASE_PATH . '/member/login');
                }

                $noreply = 'noreply@' . ((stripos($this->site->site_domain, 'www.') !== false) ? str_replace('www.', '', $this->site->site_domain) : $this->site->site_domain);

                $mail = new Moc10_Mail($rcpts, null, $this->site->site_domain . ' ' . $this->_lang->__('Member Account Modified - Password Reset'));
                $mail->setHeaders(array('From' => array($noreply, $noreply),
                                        'Reply-To' => array($noreply, $noreply)));

                $mail->setText($message);
                $mail->init();
                $mail->send();

            }

            $this->site->site_domain = $this->_postFields['site_domain'];
            $this->site->site_docroot = $this->_postFields['site_docroot'];
            $this->site->site_email = $this->_postFields['site_email'];
            $this->site->default_type_id = $this->_postFields['content_type'];
            $this->site->default_charset = $this->_postFields['default_charset'];
            $this->site->default_title = $this->_postFields['default_title'];
            $this->site->default_author = $this->_postFields['default_author'];
            $this->site->default_keywords = $this->_postFields['default_keywords'];
            $this->site->default_desc = $this->_postFields['default_desc'];
            $this->site->default_robots = $this->_postFields['default_robots'];
            $this->site->default_template_id = $this->_postFields['default_template_id'];
            $this->site->default_404 = $this->_postFields['default_404'];
            $this->site->default_date_format = $this->_postFields['default_date'];
            $this->site->default_time_format = ($this->_postFields['default_time'] != '--') ? $this->_postFields['default_time'] : '';
            $this->site->title_separator = $this->_postFields['title_separator'];
            $this->site->large_action = $this->_postFields['large_action'];
            $this->site->large_size = round(abs($lg_sz));
            $this->site->medium_action = $this->_postFields['medium_action'];
            $this->site->medium_size = round(abs($md_sz));
            $this->site->small_action = $this->_postFields['small_action'];
            $this->site->small_size = round(abs($sm_sz));
            $this->site->allowed_image_formats = implode('|', $this->_postFields['allowed_image_formats']);
            $this->site->image_max_size = $img_max_sz;
            $this->site->allowed_file_formats = implode('|', $formats);
            $this->site->file_max_size = $fle_max_sz;
            $this->site->allowed_content_types = implode('|', $this->_postFields['allowed_content_types']);
            $this->site->comment_allow = $this->_postFields['comment_allow'];
            $this->site->comment_approval = $this->_postFields['comment_approval'];
            $this->site->input_captcha = $this->_postFields['input_captcha'];
            $this->site->member_allow = $this->_postFields['member_allow'];
            $this->site->member_enable_login = $this->_postFields['member_enable_login'];
            $this->site->member_enable_registration = $this->_postFields['member_enable_registration'];
            $this->site->member_registration = $this->_postFields['member_registration'];
            $this->site->member_verification = $this->_postFields['member_verification'];
            $this->site->member_approval = $this->_postFields['member_approval'];
            $this->site->member_ssl_connection = $this->_postFields['member_ssl_connection'];
            $this->site->member_password_encoding = $this->_postFields['member_password_encoding'];
            $this->site->member_redirects = $member_redirects;
            $this->site->anon_comments = $this->_postFields['anon_comments'];
            $this->site->spam_rules = $this->_postFields['spam_rules'];
            $this->site->feed_type = $this->_postFields['feed_type'];
            $this->site->feed_limit = $this->_postFields['feed_limit'];
            $this->site->page_caching = $this->_postFields['page_caching'];
            $this->site->open_authoring = $this->_postFields['open_authoring'];
            $this->site->site_pagination_limit = $site_page_limit;
            $this->site->site_pagination_range = $site_page_range;
            $this->site->use_ssl_connection = $this->_postFields['use_ssl_connection'];
            $this->site->site_live = $this->_postFields['site_live'];

            $this->site->save();

            if ($this->site->page_caching == 'On') {
                $pages = new Phire_Table_Pages();
                $pages->findAll(null, 'site_id', $this->site->site_id);
                if (isset($pages->rows[0])) {
                    foreach($pages->rows as $pg){
                        // Get page.
                        $page = new Phire_Page($pg->page_id, $this->site->site_id, true);
                        $page->init();

                        // Get page content type from template.
                        $tmpl = new Phire_Table_Templates();
                        $tmpl->join(DB_PREFIX . 'content_types', 'type_id', null, 'template_id', $pg->template_id, 1);

                        // Get section access, if applicable.
                        if ($pg->section_id != 0) {
                            $sect = new Phire_Table_Sections();
                            $sect->findById($pg->section_id);
                            $section_access = $sect->section_access;
                        } else {
                            $section_access = 'Public';
                        }

                        // Get SSL settings for page and site.
                        $page_ssl = ($pg->force_ssl_connection == 'Yes') ? 443 : 80;
                        $site_ssl = ($this->site->use_ssl_connection == 'Yes') ? 443 : 80;

                        $cache_file_headers = $tmpl->rows[0]['type'] . "|" . $pg->page_access . '_' . $section_access . "|" . $page_ssl . '_' . $site_ssl . '|' . $pg->published . '_' . $this->site->site_live . '|' . $this->site->site_id . "\n";

                        $filename = $this->site->site_docroot . BASE_PATH . CONTENT_PATH . '/cache/' . sha1($pg->page_url) . '.txt';
                        $cache_file = new Moc10_File($filename);
                        $cache_file->write($cache_file_headers . $page->getPage());

                        if ($tmpl->mobile_template != '') {
                            $mob_filename = $this->site->site_docroot . BASE_PATH . CONTENT_PATH . '/cache/mobile/' . sha1($pg->page_url) . '.txt';
                            $mob_cache_file = new Moc10_File($mob_filename);
                            $mob_cache_file->write($cache_file_headers . $page->getMobilePage());
                        }

                    }
                }
            } else {
                $pages = new Phire_Table_Pages();
                $pages->findAll(null, 'site_id', $this->site->site_id);
                if (isset($pages->rows[0])) {
                    foreach($pages->rows as $pg){
                        $filename = $this->site->site_docroot . BASE_PATH . CONTENT_PATH . '/cache/' . sha1($pg->page_url) . '.txt';
                        $mob_filename = $this->site->site_docroot . BASE_PATH . CONTENT_PATH . '/cache/mobile/' . sha1($pg->page_url) . '.txt';
                        if (file_exists($filename)) {
                            unlink($filename);
                        }
                        if (file_exists($mob_filename)) {
                            unlink($mob_filename);
                        }
                    }
                }
            }

        // Save new site.
        } else {

            // Initialize and save the new site.
            $fields = array('site_domain' => $this->_postFields['site_domain'],
                            'site_docroot' => $this->_postFields['site_docroot'],
                            'site_email' => $this->_postFields['site_email'],
                            'default_type_id' => $this->_postFields['content_type'],
                            'default_charset' => $this->_postFields['default_charset'],
                            'default_title' => $this->_postFields['default_title'],
                            'default_author' => $this->_postFields['default_author'],
                            'default_keywords' => $this->_postFields['default_keywords'],
                            'default_desc' => $this->_postFields['default_desc'],
                            'default_robots' => $this->_postFields['default_robots'],
                            'default_template_id' => $this->_postFields['default_template_id'],
                            'default_404' => $this->_postFields['default_404'],
                            'default_date_format' => $this->_postFields['default_date'],
                            'default_time_format' => ($this->_postFields['default_time'] != '--') ? $this->_postFields['default_time'] : '',
                            'title_separator' => $this->_postFields['title_separator'],
                            'large_action' => $this->_postFields['large_action'],
                            'large_size' => round(abs($lg_sz)),
                            'medium_action' => $this->_postFields['medium_action'],
                            'medium_size' => round(abs($md_sz)),
                            'small_action' => $this->_postFields['small_action'],
                            'small_size' => round(abs($sm_sz)),
                            'allowed_image_formats' => implode('|', $this->_postFields['allowed_image_formats']),
                            'image_max_size' => $img_max_sz,
                            'allowed_file_formats' => implode('|', $formats),
                            'file_max_size' => $fle_max_sz,
                            'allowed_content_types' => implode('|', $this->_postFields['allowed_content_types']),
                            'comment_allow' => $this->_postFields['comment_allow'],
                            'comment_approval' => $this->_postFields['comment_approval'],
                            'input_captcha' => $this->_postFields['input_captcha'],
                            'member_allow' => $this->_postFields['member_allow'],
                            'member_enable_login' => $this->_postFields['member_enable_login'],
                            'member_enable_registration' => $this->_postFields['member_enable_registration'],
                            'member_registration' => $this->_postFields['member_registration'],
                            'member_verification' => $this->_postFields['member_verification'],
                            'member_approval' => $this->_postFields['member_approval'],
                            'member_ssl_connection' => $this->_postFields['member_ssl_connection'],
                            'member_password_encoding' => $this->_postFields['member_password_encoding'],
                            'member_redirects' => $member_redirects,
                            'anon_comments' => $this->_postFields['anon_comments'],
                            'spam_rules' => $this->_postFields['spam_rules'],
                            'feed_type' => $this->_postFields['feed_type'],
                            'feed_limit' => $this->_postFields['feed_limit'],
                            'page_caching' => $this->_postFields['page_caching'],
                            'open_authoring' => $this->_postFields['open_authoring'],
                            'site_pagination_limit' => $site_page_limit,
                            'site_pagination_range' => $site_page_range,
                            'use_ssl_connection' => $this->_postFields['use_ssl_connection'],
                            'site_live' => $this->_postFields['site_live']);

            $this->site = new Phire_Table_Sites($fields);
            $this->site->save();

            // Add new site to the current user's allowed sites.
            $user = new Phire_Table_Users();
            $user->findById($sess->user_id);

            $sitesAry = array();
            $sitesAry = explode('|', $user->allowed_sites);
            $sitesAry[] = $this->site->site_id;
            $sess->sites = $sitesAry;

            $open_auth_ary = $sess->open_authoring;
            $open_auth_ary[$this->site->site_id] = $this->_postFields['open_authoring'];
            $sess->open_authoring = $open_auth_ary;

            $user->allowed_sites = implode('|', $sitesAry);
            $user->save();

        }

    }

    /**
     * Method to set the post fields.
     *
     * @param  array $post
     * @return void
     */
    protected function _setFields($post = null)
    {

        if (!is_null($post)) {
            if ((!$_POST) && isset($post['site_id']) && ($post['site_id'] != 0)) {

                $this->site = new Phire_Table_Sites();
                $this->site->findById($post['site_id']);

                $mem_reg_ary = array();
                $mem_reg_ary = Moc10_String::setString($this->site->member_registration)->split('+');
                $mem_per_ary = array();
                if (in_array('Business', $mem_reg_ary)) {
                    $mem_per_ary[] = 'Business';
                }
                if (in_array('Personal', $mem_reg_ary)) {
                    $mem_per_ary[] = 'Personal';
                }
                if (in_array('Account', $mem_reg_ary)) {
                    $mem_per_ary[] = 'Account';
                }

                $img_size = explode(' ', $this->site->image_max_size);
                $fle_size = explode(' ', $this->site->file_max_size);

                $formats = array();
                $archives = array();
                $documents = array();
                $graphics = array();
                $media = array();
                $web = array();

                if ($this->site->allowed_file_formats == 'any') {
                    $alwfle = array('any');
                } else {
                    $alwfle = null;
                    $allowed_archives = array('gz', 'sit', 'tar', 'zip');
                    $allowed_documents = array('csv', 'doc|docx', 'pdf', 'ppt|pptx', 'tsv', 'txt', 'xls|xlsx');
                    $allowed_graphics = array('ai', 'bmp', 'eps', 'gif', 'jpg|jpe|jpeg', 'png', 'psd', 'tif|tiff');
                    $allowed_media = array('aif|aiff', 'avi', 'fla', 'flv', 'mov', 'mp2', 'mp3', 'mp4', 'mpg|mpeg', 'swf', 'wav', 'wma', 'wmv');
                    $allowed_web = array('css', 'html|htm|xhtml', 'js', 'php', 'sql', 'xml');
                    $formats = explode('|', $this->site->allowed_file_formats);

                    foreach ($allowed_archives as $format) {
                        if (in_array($format, $formats)) {
                            $archives[] = $format;
                        }
                    }
                    foreach ($allowed_documents as $format) {
                        if (strpos($format, 'doc') !== false) {
                            if (in_array('doc', $formats)) {
                                $documents[] = 'doc|docx';
                            }
                        } else if (strpos($format, 'ppt') !== false) {
                            if (in_array('ppt', $formats)) {
                                $documents[] = 'ppt|pptx';
                            }
                        } else if (strpos($format, 'xls') !== false) {
                            if (in_array('xls', $formats)) {
                                $documents[] = 'xls|xlsx';
                            }
                        } else if (in_array($format, $formats)) {
                            $documents[] = $format;
                        }
                    }
                    foreach ($allowed_graphics as $format) {
                        if (strpos($format, 'jpg') !== false) {
                            if (in_array('jpg', $formats)) {
                                $graphics[] = 'jpg|jpe|jpeg';
                            }
                        } else if (strpos($format, 'tif') !== false) {
                            if (in_array('tif', $formats)) {
                                $graphics[] = 'tif|tiff';
                            }
                        } else if (in_array($format, $formats)) {
                            $graphics[] = $format;
                        }
                    }
                    foreach ($allowed_media as $format) {
                        if (strpos($format, 'aif') !== false) {
                            if (in_array('aif', $formats)) {
                                $media[] = 'aif|aiff';
                            }
                        } else if (strpos($format, 'mpg') !== false) {
                            if (in_array('mpg', $formats)) {
                                $media[] = 'mpg|mpeg';
                            }
                        } else if (in_array($format, $formats)) {
                            $media[] = $format;
                        }
                    }
                    foreach ($allowed_web as $format) {
                        if (strpos($format, 'html') !== false) {
                            if (in_array('html', $formats)) {
                                $web[] = 'html|htm|xhtml';
                            }
                        } else if (in_array($format, $formats)) {
                            $web[] = $format;
                        }
                    }
                }

                $this->_postFields['site_domain'] = (string)Moc10_String::setString($this->site->site_domain)->html();
                $this->_postFields['site_docroot'] = (string)Moc10_String::setString($this->site->site_docroot)->html();
                $this->_postFields['site_email'] = $this->site->site_email;
                $this->_postFields['content_type'] = $this->site->default_type_id;
                $this->_postFields['default_charset'] = $this->site->default_charset;
                $this->_postFields['default_title'] = (string)Moc10_String::setString($this->site->default_title)->strip()->html();
                $this->_postFields['default_author'] = (string)Moc10_String::setString($this->site->default_author)->strip()->html();
                $this->_postFields['default_keywords'] = (string)Moc10_String::setString($this->site->default_keywords)->strip()->html();
                $this->_postFields['default_desc'] = (string)Moc10_String::setString($this->site->default_desc)->strip()->html();
                $this->_postFields['default_robots'] = $this->site->default_robots;
                $this->_postFields['default_template_id'] = $this->site->default_template_id;
                $this->_postFields['default_404'] = (string)Moc10_String::setString($this->site->default_404)->strip()->html();
                $this->_postFields['default_date'] = (string)Moc10_String::setString($this->site->default_date_format)->strip()->html();
                $this->_postFields['default_time'] = (string)Moc10_String::setString($this->site->default_time_format)->strip()->html();
                $this->_postFields['title_separator'] = (string)Moc10_String::setString($this->site->title_separator)->strip()->html();
                $this->_postFields['large_size'] = $this->site->large_size;
                $this->_postFields['large_action'] = $this->site->large_action;
                $this->_postFields['medium_size'] = $this->site->medium_size;
                $this->_postFields['medium_action'] = $this->site->medium_action;
                $this->_postFields['small_size'] = $this->site->small_size;
                $this->_postFields['small_action'] = $this->site->small_action;
                $this->_postFields['allowed_image_formats'] = Moc10_String::setString($this->site->allowed_image_formats)->split('|');
                $this->_postFields['image_max_size'] = $img_size[0];
                $this->_postFields['image_max_size_select'] = $img_size[1];
                $this->_postFields['allowed_file_formats'] = $alwfle;
                $this->_postFields['allowed_archives_formats'] = $archives;
                $this->_postFields['allowed_documents_formats'] = $documents;
                $this->_postFields['allowed_graphics_formats'] = $graphics;
                $this->_postFields['allowed_media_formats'] = $media;
                $this->_postFields['allowed_web_formats'] = $web;
                $this->_postFields['allowed_file_formats'] = Moc10_String::setString($this->site->allowed_file_formats)->split('|');
                $this->_postFields['file_max_size'] = $fle_size[0];
                $this->_postFields['file_max_size_select'] = $fle_size[1];
                $this->_postFields['allowed_content_types'] = Moc10_String::setString($this->site->allowed_content_types)->split('|');
                $this->_postFields['member_allow'] = $this->site->member_allow;
                $this->_postFields['member_enable_login'] = $this->site->member_enable_login;
                $this->_postFields['member_enable_registration'] = $this->site->member_enable_registration;
                $this->_postFields['member_registration'] = $mem_reg_ary[0];
                $this->_postFields['member_personal'] = $mem_per_ary;
                $this->_postFields['member_verification'] = $this->site->member_verification;
                $this->_postFields['member_approval'] = $this->site->member_approval;
                $this->_postFields['member_ssl_connection'] = $this->site->member_ssl_connection;
                $this->_postFields['member_password_encoding'] = $this->site->member_password_encoding;
                $this->_postFields['member_redirects'] = $this->site->member_redirects;
                $this->_postFields['input_captcha'] = $this->site->input_captcha;
                $this->_postFields['anon_comments'] = $this->site->anon_comments;
                $this->_postFields['comment_allow'] = $this->site->comment_allow;
                $this->_postFields['comment_approval'] = $this->site->comment_approval;
                $this->_postFields['spam_rules'] = (string)Moc10_String::setString($this->site->spam_rules)->strip()->html();
                $this->_postFields['feed_type'] = $this->site->feed_type;
                $this->_postFields['feed_limit'] = $this->site->feed_limit;
                $this->_postFields['page_caching'] = $this->site->page_caching;
                $this->_postFields['open_authoring'] = $this->site->open_authoring;
                $this->_postFields['site_pagination_limit'] = $this->site->site_pagination_limit;
                $this->_postFields['site_pagination_range'] = $this->site->site_pagination_range;
                $this->_postFields['use_ssl_connection'] = $this->site->use_ssl_connection;
                $this->_postFields['site_live'] = $this->site->site_live;
                $this->_postFields['cur_domain'] = $this->_postFields['site_domain'];
                $this->_postFields['cont_edit'] = null;
                $this->_postFields['flush_stats'] = 'No';
                $this->_postFields['plugin'] = (isset($post['plugin'])) ? $post['plugin'] : null;
                $this->_postFields['site_id'] = $this->site->site_id;

            } else if ($_POST) {
                foreach ($post as $key => $value) {
                    if (array_key_exists($key, $this->_postFields)) {
                        $this->_postFields[$key] = (isset($post[$key])) ? $post[$key] : null;
                    } else {

                    }
                }
                if (!array_key_exists('allowed_file_formats', $post)) {
                    $this->_postFields['allowed_file_formats'] = array();
                }
                if (!array_key_exists('allowed_archives_formats', $post)) {
                    $this->_postFields['allowed_archives_formats'] = array();
                }
                if (!array_key_exists('allowed_documents_formats', $post)) {
                    $this->_postFields['allowed_documents_formats'] = array();
                }
                if (!array_key_exists('allowed_graphics_formats', $post)) {
                    $this->_postFields['allowed_graphics_formats'] = array();
                }
                if (!array_key_exists('allowed_media_formats', $post)) {
                    $this->_postFields['allowed_media_formats'] = array();
                }
                if (!array_key_exists('allowed_web_formats', $post)) {
                    $this->_postFields['allowed_web_formats'] = array();
                }
                if (!in_array('3001', $this->_postFields['allowed_content_types'])) {
                    $this->_postFields['allowed_content_types'][] = '3001';
                }
                if (!in_array('3002', $this->_postFields['allowed_content_types'])) {
                    $this->_postFields['allowed_content_types'][] = '3002';
                }
                sort($this->_postFields['allowed_content_types'], SORT_NUMERIC);
            } else {
                foreach ($post as $key => $value) {
                    if (array_key_exists($key, $this->_postFields)) {
                        $this->_postFields[$key] = (isset($post[$key])) ? $post[$key] : null;
                    } else {

                    }
                }
                if (!in_array('3001', $this->_postFields['allowed_content_types'])) {
                    $this->_postFields['allowed_content_types'][] = '3001';
                }
                if (!in_array('3002', $this->_postFields['allowed_content_types'])) {
                    $this->_postFields['allowed_content_types'][] = '3002';
                }
                sort($this->_postFields['allowed_content_types'], SORT_NUMERIC);
            }
        }

    }

    /**
     * Method to set the form templates.
     *
     * @return void
     */
    protected function _setTemplates()
    {

        $back = $this->_lang->__('Back');
        $gen = $this->_lang->__('General Site Settings');
        $blue = $this->_lang->__('Blue fields are required.');
        $def = $this->_lang->__('Default Site Settings');
        $ste_img_file = $this->_lang->__('Site Image & File Settings');
        $ste_inter = $this->_lang->__('Site Interaction Settings');
        $ste_redirs = $this->_lang->__('Site Member Redirects');
        $ste_acc = $this->_lang->__('Site Access Settings');
        $cnt_ed = $this->_lang->__('Continue Editing?');
        $makesure = $this->_lang->__("Make sure that PHP's file and post settings are set correctly to accommodate file and image uploads, i.e., post_max_size, file_uploads, upload_max_filesize & max_file_uploads.");
        $enter = $this->_lang->__('Enter keywords, phrases, IP addresses (full or subnets), etc., separated by commas, to block them from the site and flag them as spam.');
        $chk_all = $this->_lang->__('Check All');
        $unchk_all = $this->_lang->__('Uncheck All');
        $inv = $this->_lang->__('Inverse');
        $mbr_ver = addslashes($this->_lang->__("In order for member verification to work properly, both the server's PHP mail function and SMTP mail agent must be configured correctly. If this is not the case, please address this issue as member verification will not function as it should."));
        $mbr_enc = addslashes($this->_lang->__("In order to deactivate member password encoding, both the server's PHP mail function and SMTP mail agent must be configured correctly to send notification emails of the members' reset passwords."));
        $cancel = $this->_lang->__('CANCEL');

        $large_sz_unit = '';
        if ($this->_postFields['large_action'] == 'Crop') {
            $large_sz_unit = 'px (squared)';
        } else if ($this->_postFields['large_action'] == 'Resize') {
            $large_sz_unit = 'px (of largest dimension)';
        } else if ($this->_postFields['large_action'] == 'Scale') {
            $large_sz_unit = '%';
        }
        $large_sz_display = (!is_null($this->_postFields['large_action']) && ($this->_postFields['large_action'] != 'None')) ? 'inline' : 'none';

        $medium_sz_unit = '';
        if ($this->_postFields['medium_action'] == 'Crop') {
            $medium_sz_unit = 'px (squared)';
        } else if ($this->_postFields['medium_action'] == 'Resize') {
            $medium_sz_unit = 'px (of largest dimension)';
        } else if ($this->_postFields['medium_action'] == 'Scale') {
            $medium_sz_unit = '%';
        }
        $medium_sz_display = (!is_null($this->_postFields['medium_action']) && ($this->_postFields['medium_action'] != 'None')) ? 'inline' : 'none';

        $small_sz_unit = '';
        if ($this->_postFields['small_action'] == 'Crop') {
            $small_sz_unit = 'px (squared)';
        } else if ($this->_postFields['small_action'] == 'Resize') {
            $small_sz_unit = 'px (of largest dimension)';
        } else if ($this->_postFields['small_action'] == 'Scale') {
            $small_sz_unit = '%';
        }
        $small_sz_display = (!is_null($this->_postFields['small_action']) && ($this->_postFields['small_action'] != 'None')) ? 'inline' : 'none';

        $cont_edit = ($this->_postFields['cont_edit'] == 'Yes') ? "checked=\"checked\" " : '';

        if (!is_null($this->_postFields['plugin'])) {
            $plugin = "<input type=\"hidden\" name=\"plugin\" value=\"{$this->_postFields['plugin']}\" />";
            $plg_lnk = BASE_PATH . CONTENT_PATH . "/extensions/plugins/{$this->_postFields['plugin']}/?sys_path=" . BASE_PATH . SYS_PATH;
            $plg_cancel = "&plugin={$this->_postFields['plugin']}";
        } else {
            $plugin = null;
            $plg_lnk = './sites.php';
            $plg_cancel = null;
        }

        // Define the main form template.
        $this->_template = <<<FORMTEMP
            <style type="text/css">
                .checkPad {
                    margin: 0;
                    padding: 0 12px 0 0;
                }
                .radioPad {
                    float: left;
                    margin: 0;
                    padding: 0 18px 0 4px;
                }
            </style>
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="{$plg_lnk}">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader">
                    <td class="grayHeader">
                        <strong style="padding-left: 25px;">{$gen}</strong>
                    </td>
                </tr>
                <tr>
                    <td style="padding: 15px 0 15px 0;">
                        <table id="entryTableWide" cellspacing="0" cellpadding="0">
                            <tr>
                                <td class="textTopRight">
                                    &nbsp;
                                </td>
                                <td colspan="5">
                                    <h4>{$blue}</h4>
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{site_domain_label}]
                                </td>
                                <td colspan="5">
                                    [{site_domain}]
                                    <div id="domainDiv">
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{site_docroot_label}]
                                </td>
                                <td colspan="5">
                                    [{site_docroot}]
                                    <div id="docrootDiv">
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{site_email_label}]<br /><br /><br />
                                </td>
                                <td colspan="5">
                                    [{site_email}]<br /><br /><br />
                                </td>
                            </tr>
                            <tr style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                <td colspan="6" style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                    <strong style="font-size: 0.85em; padding-left: 22px;">{$def}</strong>
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight" style="padding-top: 7px;">
                                    <br />
                                    [{allowed_content_types_label}]<br />
                                    <a class="smallOrangeLink" href="#" onclick="addSiteFrm.checkAll('allowed_content_types', Array('3001', '3002')); return false;">[ {$chk_all} ]</a> <span class="grayPad" style="padding: 0 2px 0 2px;">|</span> <a class="smallOrangeLink" href="#" onclick="addSiteFrm.uncheckAll('allowed_content_types', Array('3001', '3002')); return false;">[ {$unchk_all} ]</a>
                                </td>
                                <td colspan="5" style="vertical-align: top;">
                                    <br />
                                    [{allowed_content_types}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{content_type_label}]
                                </td>
                                <td>
                                    [{content_type}]
                                </td>
                                <td class="textTopRight">
                                    [{default_charset_label}]
                                </td>
                                <td>
                                    [{default_charset}]
                                </td>
                                <td class="textTopRight">
                                    [{default_robots_label}]
                                </td>
                                <td>
                                    [{default_robots}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="6">
                                    &nbsp;
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{default_title_label}]
                                </td>
                                <td colspan="3">
                                    [{default_title}]
                                </td>
                                <td class="textTopRight">
                                    [{title_separator_label}]
                                </td>
                                <td>
                                    [{title_separator}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{default_author_label}]
                                </td>
                                <td colspan="5">
                                    [{default_author}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{default_keywords_label}]
                                </td>
                                <td colspan="5">
                                    [{default_keywords}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{default_desc_label}]
                                </td>
                                <td colspan="5">
                                    [{default_desc}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{default_template_id_label}]
                                </td>
                                <td colspan="5">
                                    [{default_template_id}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{default_404_label}]
                                </td>
                                <td colspan="5">
                                    [{default_404}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{default_date_label}]<br /><br /><br />
                                </td>
                                <td colspan="5">
                                    [{default_date}]
                                    [{default_time_label}]
                                    [{default_time}]<br /><br /><br />
                                </td>
                            </tr>
                            <tr style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                <td colspan="6" style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                    <a class="right" id="siteImageLink" href="#" onclick="addSiteFrm.show('siteImage'); return false;">[+]</a><strong style="font-size: 0.85em; padding-left: 22px;">{$ste_img_file}</strong>
                                </td>
                            </tr>
                            <tr id="siteImageFormats" style="display: none;">
                                <td class="textTopRight" style="padding-top: 7px;">
                                    <br />
                                    [{allowed_image_formats_label}]
                                </td>
                                <td colspan="5">
                                    <br />
                                    [{allowed_image_formats}]
                                    <a class="smallOrangeLink" href="#" onclick="addSiteFrm.checkAll('allowed_image_formats'); return false;">[ {$chk_all} ]</a> <span class="grayPad" style="padding: 0 2px 0 2px;">|</span> <a class="smallOrangeLink" href="#" onclick="addSiteFrm.uncheckAll('allowed_image_formats'); return false;">[ {$unchk_all} ]</a> <span class="grayPad" style="padding: 0 2px 0 2px;">|</span> <a class="smallOrangeLink" href="#" onclick="addSiteFrm.checkInverse('allowed_image_formats'); return false;">[ {$inv} ]</a><br /><br />
                                </td>
                            </tr>
                            <tr id="siteFileFormats" style="display: none;">
                                <td class="textTopRight" style="padding-top: 7px;">
                                    <label for="allowed_file_formats" class="required">Allowed File Formats:</label>
                                </td>
                                <td colspan="5" id="fileFormatsTd" style="vertical-align: top; padding-top: 5px;">
                                    [{allowed_file_formats}]
                                    <div style="width: 800px; margin: 5px 0 5px 0; padding: 5px 0 5px 0; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc; color: #aaa;"><strong><em>or, filter by:</em></strong></div>
                                    [{allowed_archives_formats_label}]
                                    [{allowed_archives_formats}]
                                    <a class="smallOrangeLink" href="#" onclick="addSiteFrm.checkAll('allowed_archives_formats'); return false;">[ {$chk_all} ]</a> <span class="grayPad" style="padding: 0 2px 0 2px;">|</span> <a class="smallOrangeLink" href="#" onclick="addSiteFrm.uncheckAll('allowed_archives_formats'); return false;">[ {$unchk_all} ]</a> <span class="grayPad" style="padding: 0 2px 0 2px;">|</span> <a class="smallOrangeLink" href="#" onclick="addSiteFrm.checkInverse('allowed_archives_formats'); return false;">[ {$inv} ]</a><br /><br />
                                    [{allowed_documents_formats_label}]
                                    [{allowed_documents_formats}]
                                    <a class="smallOrangeLink" href="#" onclick="addSiteFrm.checkAll('allowed_documents_formats'); return false;">[ {$chk_all} ]</a> <span class="grayPad" style="padding: 0 2px 0 2px;">|</span> <a class="smallOrangeLink" href="#" onclick="addSiteFrm.uncheckAll('allowed_documents_formats'); return false;">[ {$unchk_all} ]</a> <span class="grayPad" style="padding: 0 2px 0 2px;">|</span> <a class="smallOrangeLink" href="#" onclick="addSiteFrm.checkInverse('allowed_documents_formats'); return false;">[ {$inv} ]</a><br /><br />
                                    [{allowed_graphics_formats_label}]
                                    [{allowed_graphics_formats}]
                                    <a class="smallOrangeLink" href="#" onclick="addSiteFrm.checkAll('allowed_graphics_formats'); return false;">[ {$chk_all} ]</a> <span class="grayPad" style="padding: 0 2px 0 2px;">|</span> <a class="smallOrangeLink" href="#" onclick="addSiteFrm.uncheckAll('allowed_graphics_formats'); return false;">[ {$unchk_all} ]</a> <span class="grayPad" style="padding: 0 2px 0 2px;">|</span> <a class="smallOrangeLink" href="#" onclick="addSiteFrm.checkInverse('allowed_graphics_formats'); return false;">[ {$inv} ]</a><br /><br />
                                    [{allowed_media_formats_label}]
                                    [{allowed_media_formats}]
                                    <a class="smallOrangeLink" href="#" onclick="addSiteFrm.checkAll('allowed_media_formats'); return false;">[ {$chk_all} ]</a> <span class="grayPad" style="padding: 0 2px 0 2px;">|</span> <a class="smallOrangeLink" href="#" onclick="addSiteFrm.uncheckAll('allowed_media_formats'); return false;">[ {$unchk_all} ]</a> <span class="grayPad" style="padding: 0 2px 0 2px;">|</span> <a class="smallOrangeLink" href="#" onclick="addSiteFrm.checkInverse('allowed_media_formats'); return false;">[ {$inv} ]</a><br /><br />
                                    [{allowed_web_formats_label}]
                                    [{allowed_web_formats}]
                                    <a class="smallOrangeLink" href="#" onclick="addSiteFrm.checkAll('allowed_web_formats'); return false;">[ {$chk_all} ]</a> <span class="grayPad" style="padding: 0 2px 0 2px;">|</span> <a class="smallOrangeLink" href="#" onclick="addSiteFrm.uncheckAll('allowed_web_formats'); return false;">[ {$unchk_all} ]</a> <span class="grayPad" style="padding: 0 2px 0 2px;">|</span> <a class="smallOrangeLink" href="#" onclick="addSiteFrm.checkInverse('allowed_web_formats'); return false;">[ {$inv} ]</a>
                                </td>
                            </tr>
                            <tr id="siteImageBlank" style="display: none;">
                                <td colspan="6">
                                    &nbsp;
                                </td>
                            </tr>
                            <tr id="siteImageLargeAction" style="display: none;">
                                <td class="textTopRight" style="padding-top: 7px;">
                                    [{large_action_label}]<br />
                                </td>
                                <td style="vertical-align: top;">
                                    [{large_action}] <span id="largeDisplaySpan" style="display: {$large_sz_display};">to [{large_size}] <span id="largeSpan">{$large_sz_unit}</span></span><br />
                                </td>
                                <td class="textTopRight">
                                    [{image_max_size_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{image_max_size}]
                                    [{image_max_size_select}]
                                </td>
                                <td>
                                    &nbsp;<br />
                                </td>
                                <td>
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr id="siteImageMediumAction" style="display: none;">
                                <td class="textTopRight" style="padding-top: 7px;">
                                    [{medium_action_label}]<br />
                                </td>
                                <td style="vertical-align: top;">
                                    [{medium_action}] <span id="mediumDisplaySpan" style="display: {$medium_sz_display};">to [{medium_size}] <span id="mediumSpan">{$medium_sz_unit}</span></span><br />
                                </td>
                                <td class="textTopRight">
                                    [{file_max_size_label}]<br />
                                </td>
                                <td style="vertical-align: top;">
                                    [{file_max_size}]
                                    [{file_max_size_select}]<br />
                                </td>
                                <td>
                                    &nbsp;<br />
                                </td>
                                <td>
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr id="siteImageSmallAction" style="display: none;">
                                <td class="textTopRight" style="padding-top: 7px;">
                                    [{small_action_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{small_action}] <span id="smallDisplaySpan" style="display: {$small_sz_display};">to [{small_size}] <span id="smallSpan">{$small_sz_unit}</span></span>
                                </td>
                                <td class="textTopRight">
                                    &nbsp;<br />
                                </td>
                                <td style="vertical-align: top;">
                                    &nbsp;<br />
                                </td>
                                <td>
                                    &nbsp;<br />
                                </td>
                                <td>
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr id="siteImageText" style="display: none;">
                                <td class="textTopRight" style="padding-top: 7px;">
                                    &nbsp;<br /><br /><br />
                                </td>
                                <td style="vertical-align: top;" colspan="5">
                                    <em style="font-size: 0.85em;">({$makesure})</em><br /><br /><br />
                                </td>
                            </tr>
                            <tr style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                <td colspan="6" style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                    <a class="right" id="siteInteractionLink" href="#" onclick="addSiteFrm.show('siteInteraction'); return false;">[+]</a><strong style="font-size: 0.85em; padding-left: 22px;">{$ste_inter}</strong>
                                </td>
                            </tr>
                            <tr id="siteInteractionRow1" style="display: none;">
                                <td class="textTopRight">
                                    <br />
                                    [{comment_allow_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    <br />
                                    [{comment_allow}]
                                </td>
                                <td class="textTopRight">
                                    <br />
                                    [{comment_approval_label}]
                                </td>
                                <td>
                                    <br />
                                    [{comment_approval}]
                                </td>
                                <td class="textTopRight">
                                    <br />
                                    [{member_enable_registration_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    <br />
                                    [{member_enable_registration}]
                                </td>
                            </tr>
                            <tr id="siteInteractionRow2" style="display: none;">
                                <td class="textTopRight">
                                    [{anon_comments_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{anon_comments}]
                                </td>
                                <td class="textTopRight">
                                    [{member_verification_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{member_verification}]
                                </td>
                                <td class="textTopRight">
                                    [{member_enable_login_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{member_enable_login}]
                                </td>
                            </tr>
                            <tr id="siteInteractionRow3" style="display: none;">
                                <td class="textTopRight">
                                    [{member_allow_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{member_allow}]
                                </td>
                                <td class="textTopRight">
                                    [{member_approval_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{member_approval}]
                                </td>
                                <td class="textTopRight">
                                    [{member_registration_label}]
                                </td>
                                <td style="vertical-align: top; margin: 0; padding: 3px 0 0 0;">
                                    [{member_registration}]
                                </td>
                            </tr>
                            <tr id="siteInteractionRow4" style="display: none;">
                                <td class="textTopRight">
                                    [{member_ssl_connection_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{member_ssl_connection}]
                                </td>
                                <td class="textTopRight">
                                    [{member_password_encoding_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{member_password_encoding}]
                                </td>
                                <td class="textTopRight">
                                    &nbsp;
                                </td>
                                <td style="vertical-align: top;">
                                    <div id="memberPersonal">
                                        [{member_personal}]
                                    </div>
                                </td>
                            </tr>
                            <tr id="siteInteractionRow5" style="display: none;">
                                <td class="textTopRight">
                                    <br />
                                    [{spam_rules_label}]
                                </td>
                                <td colspan="5">
                                    <em style="font-size: 0.85em;">({$enter})</em><br />
                                    [{spam_rules}]
                                </td>
                            </tr>
                            <tr id="siteInteractionRow6" style="display: none;">
                                <td class="textTopRight">
                                    <br />
                                    [{input_captcha_label}]<br /><br />
                                </td>
                                <td colspan="5" style="vertical-align: top;">
                                    <br />
                                    [{input_captcha}]<br /><br />
                                </td>
                            </tr>
                            <tr style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                <td colspan="6" style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                    <a class="right" id="memberRedirectsLink" href="#" onclick="addSiteFrm.show('memberRedirects'); return false;">[+]</a><strong style="font-size: 0.85em; padding-left: 22px;">{$ste_redirs}</strong>
                                </td>
                            </tr>
                            <tr id="memberRedirectsTr" style="display: none;">
                                <td colspan="6">
                                    <table id="memberRedirectTable" cellpadding="0" cellspacing="0">
                                        <tr>
                                            <td class="textTopRight">
                                                <br />
                                                [{verify_redirect_label}]
                                            </td>
                                            <td>
                                                <br />
                                                [{verify_redirect}]
                                            </td>
                                            <td class="textTopRight">
                                                <br />
                                                [{login_redirect_label}]
                                            </td>
                                            <td>
                                                <br />
                                                [{login_redirect}]
                                            </td>
                                            <td class="textTopRight">
                                                <br />
                                                [{logout_redirect_label}]
                                            </td>
                                            <td>
                                                <br />
                                                [{logout_redirect}]
                                            </td>
                                            <td class="textTopRight">
                                                <br />
                                                [{forgot_redirect_label}]
                                            </td>
                                            <td>
                                                <br />
                                                [{forgot_redirect}]
                                            </td>
                                        </tr>
                                        <tr>
                                            <td class="textTopRight">
                                                [{register_redirect_label}]
                                            </td>
                                            <td>
                                                [{register_redirect}]
                                            </td>
                                            <td class="textTopRight">
                                                [{profile_redirect_label}]
                                            </td>
                                            <td>
                                                [{profile_redirect}]
                                            </td>
                                            <td class="textTopRight">
                                                [{delete_redirect_label}]
                                            </td>
                                            <td colspan="3">
                                                [{delete_redirect}]
                                            </td>
                                        </tr>
                                    </table><br />
                                </td>
                            </tr>
                            <tr style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                <td colspan="6" style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                    <strong style="font-size: 0.85em; padding-left: 22px;">{$ste_acc}</strong>
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    <br />
                                    [{flush_stats_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    <br />
                                    [{flush_stats}]
                                </td>
                                <td class="textTopRight">
                                    <br />
                                    [{site_pagination_limit_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    <br />
                                    [{site_pagination_limit}] <span class="grayPad">x</span> [{site_pagination_range}]
                                </td>
                                <td class="textTopRight">
                                    <br />
                                    [{feed_limit_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    <br />
                                    [{feed_limit}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{use_ssl_connection_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{use_ssl_connection}]
                                </td>
                                <td class="textTopRight">
                                    [{page_caching_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{page_caching}]
                                </td>
                                <td class="textTopRight">
                                    [{feed_type_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{feed_type}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{site_live_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{site_live}]
                                </td>
                                <td class="textTopRight">
                                    [{open_authoring_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{open_authoring}]
                                </td>
                                <td class="textTopRight" colspan="2">
                                    &nbsp;
                                </td>
                            </tr>
                            <tr>
                                <td colspan="6">
                                    &nbsp;
                                </td>
                            </tr>
                            <tr>
                                <td>
                                    <span style="float: right; margin: 0; padding: 0; text-align: right;"><input style="float: right; margin: 0 0 0 8px; padding: 0;" type="checkbox" class="checkBox" name="cont_edit" id="cont_edit" value="Yes" {$cont_edit}/>{$cnt_ed}</span>
                                </td>
                                <td colspan="5">
                                    [{submit}] [{site_id}] [{cur_domain}] <a style="margin: 0 0 0 10px; padding-top: 6px; height: 19px; font-size: 0.825em; float: left;" class="submitGrayBtn" href="../core/process/add.site.php?action=cancel{$plg_cancel}">{$cancel}</a> {$plugin}
                                </td>
                            </tr>
                        </table>
                        <script type="text/javascript">
                            addSiteFormInit();
                            addSiteFrm.fo.site_domain.focus();
                            var xmlhttp = new JaxXmlHttp();
                            var memVer = document.getElementById('member_verification1');
                            var memPass = document.getElementById('member_password_encoding');
                            memVer.onclick = function() {
                                alert('{$mbr_ver}');
                            }
                            memPass.onclick = function() {
                                alert('{$mbr_enc}');
                            }
                        </script>
                    </td>
                </tr>
            </table>
FORMTEMP;

    }

}
