<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_Template
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_Template extends Moc10_Form
{

    /**
     * Template object
     * @var Phire_Table_Templates
     */
    public $tmpl = null;

    /**
     * Form templates
     * @var array
     */
    protected $_templates = array('main' => null, 'mobile' => null);

    /**
     * $_POST fields
     * @var array
     */
    protected $_postFields = array('plugin' => null,
                                   'site_id' => null,
                                   'theme_id' => null,
                                   'type_id' => null,
                                   'template_name' => null,
                                   'template' => null,
                                   'mobile_template' => null,
                                   'cont_edit' => null,
                                   'mobile' => null,
                                   'cur_template_name' => null,
                                   'template_id' => 0);

    /**
     * Initialization method for the template form.
     *
     * @param  array $post
     * @return void
     */
    public function init($post = null)
    {

        $lang = new Phire_Language();

        $this->_setFields($post);
        $this->_setTemplates();

        $this->setAttributes('id', 'addTemplateForm');

        $sess = Moc10_Session::getInstance();

        $sitesAry = Phire_Sites::getAllowedSites(true);

        $site = new Phire_Table_Sites();
        $site_types = array();

        if ($this->_postFields['site_id'] != 0) {
            $site->findById($this->_postFields['site_id']);
        } else {
            $site->findById($sitesAry['first_site_id']);
        }

        $site_types = explode('|', $site->allowed_content_types);

        $types = new Phire_Table_ContentTypes();
        $types->findAll('type_id ASC');
        $typeAry = array();
        foreach ($types->rows as $type) {
            if (in_array($type->type_id, $site_types)) {
                $typeAry[$type->type_id] = $type->type;
            }
        }
        // Create the 'type_id' form element.
        $type_id = new Moc10_Form_Element_Select('type_id', $typeAry, $this->_postFields['type_id']);
        $type_id->setLabel($lang->__('Content Type:'));

        // Get the themes.
        $themes = new Phire_Table_Themes();
        $themes->findAll('theme_id ASC');
        $themeAry = array('0' => '(' . $lang->__('None') . ')');

        if (isset($themes->rows[0])) {
            foreach ($themes->rows as $theme) {
                if (in_array($theme->site_id, $sess->sites)) {
                    $themeAry[$theme->theme_id] = $theme->theme_name;
                }
            }
        }

        // Create the 'theme_id' form element.
        $theme_id = new Moc10_Form_Element_Select('theme_id', $themeAry, $this->_postFields['theme_id']);
        $theme_id->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Theme?') : $lang->__('Assign to Theme?')));

        // Create the 'template_name' form element.
        $template_name = new Moc10_Form_Element('text', 'template_name', $this->_postFields['template_name']);
        $template_name->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Name:') : $lang->__('Template Name:')));
        $template_name->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '25' : '150'));
        $template_name->setRequired(true);

        if ((!is_null($this->_postFields['template_name'])) && ($this->_postFields['template_name'] != $this->_postFields['cur_template_name'])) {
            $dupe_tmpl = new Phire_Table_Templates();
            $dupe_tmpl->execute("SELECT * FROM " . DB_PREFIX . "templates WHERE template_name = '" . (string)Moc10_String::setString($this->_postFields['template_name'])->escape()->striptags() . "' AND site_id = '" . (string)Moc10_String::setString($this->_postFields['site_id'])->escape(true)->striptags() . "' LIMIT 1");
            if (isset($dupe_tmpl->rows[0]['template_id'])) {
                $template_name->addValidator('NotEqual', true, $dupe_tmpl->rows[0]['template_name'], $lang->__('That template name already exists in the system for that site. Please choose another template name.'));
            }
        }

        // Create the 'template' form element.
        $template = new Moc10_Form_Element_Textarea('template', $this->_postFields['template']);
        $template->setLabel($lang->__('Template:'));
        $template->setAttributes('cols', ((!is_null($this->_postFields['mobile'])) ? '25' : '150'));
        $template->setAttributes('rows', ((!is_null($this->_postFields['mobile'])) ? '8' : '20'));
        $template->setAttributes('spellcheck', 'false');
        $template->setAttributes('wrap', 'off');
        $template->setRequired(true);

        // Create the 'mobile_template' form element.
        $mobile_template = new Moc10_Form_Element_Textarea('mobile_template', $this->_postFields['mobile_template']);
        $mobile_template->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Mobile:') : $lang->__('Mobile Template:')));
        $mobile_template->setAttributes('cols', ((!is_null($this->_postFields['mobile'])) ? '25' : '150'));
        $mobile_template->setAttributes('rows', ((!is_null($this->_postFields['mobile'])) ? '6' : '15'));
        $mobile_template->setAttributes('spellcheck', 'false');
        $mobile_template->setAttributes('wrap', 'off');

        // Create the 'cur_template_name' form element.
        $cur_template_name = new Moc10_Form_Element('hidden', 'cur_template_name', $this->_postFields['cur_template_name']);

        // Create the 'template_id' form element.
        $template_id = new Moc10_Form_Element('hidden', 'template_id', $this->_postFields['template_id']);

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $lang->__('SAVE'));
        $submit->setAttributes('style', 'float: right;');

        // Set whether it's a mobile form or not.
        if (!is_null($this->_postFields['mobile'])) {
            $sess = Moc10_Session::getInstance();
            $submit->setAttributes('class', 'submitBtn');
            $site_id = new Moc10_Form_Element('hidden', 'site_id', $sess->cur_site_id);
            $this->setTemplate($this->_templates['mobile']);
        } else {
            $this->setAttributes('onsubmit', "return addTemplateFrm.validate();");
            $site_id = new Moc10_Form_Element_Select('site_id', $sitesAry['sites'], $this->_postFields['site_id']);
            $submit->setAttributes('class', 'submitBtn');
            $site_id->setLabel($lang->__('Add to Site:'));
            $site_id->setAttributes('onchange', "xmlhttp.getRequest('../core/process/check.types.php?site_id=' + this.value, addTemplateFrm.changeTypes); return false;");
            $template_name->setAttributes('onkeyup', "xmlhttp.getRequest('../core/process/check.template.php?current=" . $this->_postFields['cur_template_name'] . "&tmpl_name=' + this.value + '&site_id=' + addTemplateFrm.fo.site_id.value, addTemplateFrm.checkTemplate); return false;");
            $template_name->setAttributes('style', 'width: 800px;');
            $template->setAttributes('style', 'width: 800px;');
            $mobile_template->setAttributes('style', 'width: 800px;');
            $this->setTemplate($this->_templates['main']);
        }

        $this->addElements(array($theme_id, $site_id, $type_id, $template_name, $template, $mobile_template, $submit, $cur_template_name, $template_id));

    }

    /**
     * Method to save the template data.
     *
     * @return void
     */
    public function saveData()
    {

        if ($this->_postFields['template_id'] != 0) {

            $this->tmpl = new Phire_Table_Templates();
            $this->tmpl->findById($this->_postFields['template_id']);

            $old_thm = $this->tmpl->theme_id;

            $this->tmpl->site_id = $this->_postFields['site_id'];
            $this->tmpl->theme_id = $this->_postFields['theme_id'];
            $this->tmpl->type_id = $this->_postFields['type_id'];
            $this->tmpl->template_name = $this->_postFields['template_name'];
            $this->tmpl->template = $this->_postFields['template'];
            $this->tmpl->mobile_template = $this->_postFields['mobile_template'];

            $this->tmpl->save();

            if ($this->_postFields['theme_id'] != 0) {
                $theme = new Phire_Table_Themes();
                $theme->findById($this->_postFields['theme_id']);
                if (strpos($theme->templates, $this->tmpl->template_id) === false) {
                    $themeAry = explode('|', $theme->templates);
                    $themeAry[] = $this->tmpl->template_id;
                    $theme->templates = implode('|', $themeAry);
                    $theme->save();
                }
            } else if ($old_thm != 0) {
                $theme = new Phire_Table_Themes();
                $theme->findById($old_thm);
                if (strpos($theme->templates, $this->tmpl->template_id) !== false) {
                    $themeAry = explode('|', $theme->templates);
                    $key = array_search($this->tmpl->template_id, $themeAry);
                    unset($themeAry[$key]);
                    $theme->templates = implode('|', $themeAry);
                    $theme->save();
                }
            }

            $this->tmpl->save();

        } else {

            // Add the new template in the system.
            $fields = array('site_id' => $this->_postFields['site_id'],
                            'theme_id' => $this->_postFields['theme_id'],
                            'type_id' => $this->_postFields['type_id'],
                            'template_name' => $this->_postFields['template_name'],
                            'template' => $this->_postFields['template'],
                            'mobile_template' => $this->_postFields['mobile_template']);
            $this->tmpl = new Phire_Table_Templates($fields);
            $this->tmpl->save();

            if ($this->_postFields['theme_id'] != 0) {
                $theme = new Phire_Table_Themes();
                $theme->findById($this->_postFields['theme_id']);
                $themeAry = explode('|', $theme->templates);
                $themeAry[] = $this->tmpl->template_id;
                $theme->templates = implode('|', $themeAry);
                $theme->save();
            }

        }

    }

    /**
     * Method to set the post fields.
     *
     * @param  array $post
     * @return void
     */
    protected function _setFields($post = null)
    {

        if (!is_null($post)) {
            if ((!$_POST) && isset($post['template_id']) && ($post['template_id'] != 0)) {

                $this->tmpl = new Phire_Table_Templates();
                $this->tmpl->findById($post['template_id']);

                $this->_postFields['site_id'] = $this->tmpl->site_id;
                $this->_postFields['theme_id'] = $this->tmpl->theme_id;
                $this->_postFields['type_id'] = $this->tmpl->type_id;
                $this->_postFields['template_name'] = (string)Moc10_String::setString($this->tmpl->template_name)->strip()->html();
                $this->_postFields['template'] = (string)Moc10_String::setString($this->tmpl->template)->strip()->html();
                $this->_postFields['mobile_template'] = (string)Moc10_String::setString($this->tmpl->mobile_template)->strip()->html();
                $this->_postFields['cont_edit'] = (isset($post['cont_edit'])) ? $post['cont_edit'] : null;
                $this->_postFields['cur_template_name'] = $this->_postFields['template_name'];
                $this->_postFields['plugin'] = (isset($post['plugin'])) ? $post['plugin'] : null;
                $this->_postFields['mobile'] = (isset($post['mobile'])) ? $post['mobile'] : null;
                $this->_postFields['template_id'] = $this->tmpl->template_id;

            } else {
                foreach ($post as $key => $value) {
                    if (array_key_exists($key, $this->_postFields)) {
                        $this->_postFields[$key] = (isset($post[$key])) ? $post[$key] : null;
                    }
                }
            }
        }

    }

    /**
     * Method to set the form templates.
     *
     * @return void
     */
    protected function _setTemplates()
    {

        $lang = new Phire_Language();
        $back = $lang->__('Back');
        $blue = $lang->__('Blue fields are required.');
        $cont_ed = $lang->__('Continue Editing?');
        $cancel = $lang->__('CANCEL');

        $cont_edit = ($this->_postFields['cont_edit'] == 'Yes') ? "checked=\"checked\" " : '';

        if (!is_null($this->_postFields['plugin'])) {
            $plugin = "<input type=\"hidden\" name=\"plugin\" value=\"{$this->_postFields['plugin']}\" />";
            $plg_lnk = BASE_PATH . CONTENT_PATH . "/extensions/plugins/{$this->_postFields['plugin']}/?sys_path=" . BASE_PATH . SYS_PATH;
            $plg_cancel = "&plugin={$this->_postFields['plugin']}";
        } else {
            $plugin = null;
            $plg_lnk = './templates.php';
            $plg_cancel = null;
        }

        // Define the main form template.
        $this->_templates['main'] = <<<FORMTEMP
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="{$plg_lnk}">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader">
                    <td class="grayHeader">
                        &nbsp;
                    </td>
                </tr>
                <tr>
                    <td style="padding: 15px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td colspan="2">
                                    <h4>{$blue}</h4>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{type_id_label}]
                                </td>
                                <td id="typeTD">
                                    [{type_id}]
                                </td>
                                <td class="textRight">
                                    [{site_id_label}]
                                    [{site_id}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{theme_id_label}]
                                </td>
                                <td colspan="2">
                                    <div id="themeDiv">
                                        [{theme_id}]
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{template_name_label}]
                                </td>
                                <td colspan="2">
                                    [{template_name}]
                                    <div id="tmplNameDiv">
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{template_label}]
                                </td>
                                <td colspan="2">
                                    [{template}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{mobile_template_label}]
                                </td>
                                <td colspan="2">
                                    [{mobile_template}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="3">
                                    <a style="margin: 0 0 0 10px; padding-top: 6px; height: 19px; font-size: 0.825em; float: right;" class="submitGrayBtn" href="../core/process/add.template.php?action=cancel{$plg_cancel}">{$cancel}</a> [{submit}] <span style="float: right; margin: 5px 15px 0 0; padding: 0; text-align: right;"><input style="float: right; margin: 0 0 0 8px; padding: 0;" type="checkbox" class="checkBox" name="cont_edit" id="cont_edit" value="Yes" {$cont_edit}/>{$cont_ed}</span> [{template_id}] [{cur_template_name}] {$plugin}
                                </td>
                            </tr>
                        </table>
                        <script type="text/javascript">
                            addTemplateFormInit();
                            var xmlhttp = new JaxXmlHttp();
                        </script>
                    </td>
                </tr>
            </table>
FORMTEMP;

        $mobile = (!is_null($this->_postFields['mobile'])) ? "<input type=\"hidden\" name=\"mobile\" value=\"true\" />" : null;

        // Define the mobile form template.
        $this->_templates['mobile'] = <<<FORMTEMP
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="./templates.php">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader" style="height; 16px;">
                    <td class="grayHeader" style="height; 16px;">
                        &nbsp;
                    </td>
                </tr>
                <tr>
                    <td style="padding: 5px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td>
                                    <h4>{$blue}</h4>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{type_id_label}]
                                </td>
                                <td id="typeTD">
                                    [{type_id}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{theme_id_label}]
                                </td>
                                <td>
                                    <div id="themeDiv">
                                        [{theme_id}]
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{template_name_label}]
                                </td>
                                <td>
                                    [{template_name}]
                                    <div id="tmplNameDiv">
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{template_label}]
                                </td>
                                <td>
                                    [{template}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{mobile_template_label}]
                                </td>
                                <td>
                                    [{mobile_template}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    <a style="float: right; margin: 0 0 0 5px; padding: 2px 3px 4px 3px; height: 10px; font-size: 0.9em;" class="submitBtnGray" href="../../core/process/add.template.php?action=cancel&mobile=true">{$cancel}</a> [{submit}] <span style="float: right; margin: 5px 15px 0 0; padding: 0; text-align: right;"><input style="float: right; margin: 0 0 0 8px; padding: 0;" type="checkbox" class="checkBox" name="cont_edit" id="cont_edit" value="Yes" {$cont_edit}/>{$cont_ed}</span> [{template_id}] [{cur_template_name}] [{site_id}] {$mobile}
                                </td>
                            </tr>
                        </table>
                    </td>
                </tr>
            </table>
FORMTEMP;

    }

}

