<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Table
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Table_Sites
 *
 * @category   Phire
 * @package    Phire_Table
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Table_Sites extends Moc10_Record
{

    /**
     * Table name of the database table
     * @var string
     */
    protected $_tableName = 'sites';

    /**
     * Primary ID field name of the database table
     * @var string
     */
    protected $_primaryId = 'site_id';

    /**
     * Constructor
     *
     * Instantiate the database record object.
     *
     * @param array  $fields
     * @param string $type
     * @param string $dbase
     * @param string $host
     * @param string $user
     * @param string $pass
     * @throws Exception
     * @return void
     */
    public function __construct($fields = null, $type = null, $db = null, $host = null, $user = null, $pass = null)
    {

        if (!isset($this->_tableName)) {
            throw new Exception('Error: Table name not set.');
        } else {
            $this->_tableName = DB_PREFIX . $this->_tableName;
            parent::__construct($fields, $type, $db, $host, $user, $pass);
        }

    }

    /**
     * Get the site
     *
     * @param  int|string $id
     * @return void
     */
    public function getSite($id = null)
    {

        $db_prefix = DB_PREFIX;

        $sql = <<<SQLSELECT
SELECT
 {$db_prefix}sites.site_id,
 {$db_prefix}sites.site_domain,
 {$db_prefix}sites.site_docroot,
 {$db_prefix}sites.site_email,
 {$db_prefix}sites.default_type_id,
 {$db_prefix}sites.default_charset,
 {$db_prefix}sites.default_title,
 {$db_prefix}sites.default_author,
 {$db_prefix}sites.default_keywords,
 {$db_prefix}sites.default_desc,
 {$db_prefix}sites.default_robots,
 {$db_prefix}sites.default_template_id,
 {$db_prefix}sites.default_404,
 {$db_prefix}sites.default_date_format,
 {$db_prefix}sites.default_time_format,
 {$db_prefix}sites.title_separator,
 {$db_prefix}sites.page_caching,
 {$db_prefix}sites.use_ssl_connection,
 {$db_prefix}sites.site_live,
 {$db_prefix}sites.member_allow,
 {$db_prefix}sites.member_enable_login,
 {$db_prefix}sites.member_enable_registration,
 {$db_prefix}sites.member_registration,
 {$db_prefix}sites.member_verification,
 {$db_prefix}sites.member_approval,
 {$db_prefix}sites.member_ssl_connection,
 {$db_prefix}sites.member_password_encoding,
 {$db_prefix}sites.member_redirects,
 {$db_prefix}sites.input_captcha,
 {$db_prefix}sites.spam_rules,
 {$db_prefix}sites.site_pagination_limit,
 {$db_prefix}sites.site_pagination_range,
 {$db_prefix}content_types.type,
 {$db_prefix}charsets.charset,
 {$db_prefix}robots.robots

 FROM {$db_prefix}sites

 LEFT JOIN {$db_prefix}content_types ON {$db_prefix}sites.default_type_id = {$db_prefix}content_types.type_id
 LEFT JOIN {$db_prefix}charsets ON {$db_prefix}sites.default_charset = {$db_prefix}charsets.charset_id
 LEFT JOIN {$db_prefix}robots ON {$db_prefix}sites.default_robots = {$db_prefix}robots.robot_id

SQLSELECT;

        // Get site based on the HTTP_HOST passed.
        if (is_null($id)) {
            $this->execute($sql . " WHERE site_domain = '" . $_SERVER['HTTP_HOST'] . "' LIMIT 1");
            // If none found, attempt with a leading 'www.'
            if (!isset($this->rows[0])) {
                $this->execute($sql . " WHERE site_domain = 'www." . $_SERVER['HTTP_HOST'] . "' LIMIT 1");
            }
        // Else, if numeric ID passed, get site by ID.
        } else if (is_numeric($id)) {
            $this->execute($sql . " WHERE site_id = '" . $id . "' LIMIT 1");
        // Else, if string passed, get site by domain name.
        } else {
            $this->execute($sql . " WHERE site_domain = '" . $id . "' LIMIT 1");
        }

        if (isset($this->rows[0])) {
            $this->_fields = $this->rows[0];
        } else {
            $this->_fields = null;
        }

    }

    /**
     * Get member count of a site
     *
     * @param  int|string $sid
     * @return int
     */
    public function get404s($sid)
    {

        $site404s = 0;
        $site = new Phire_Table_Sites();
        $site->execute("SELECT site_id, SUM(requests) as error_count from " . DB_PREFIX . "404s WHERE site_id = '" . $sid . "' GROUP BY site_id");

        if (isset($site->site_id)) {
            $site404s = $site->error_count;
        }

        return $site404s;

    }

}
