<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_TagCloud
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_TagCloud
 *
 * @category   Phire
 * @package    Phire_TagCloud
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_TagCloud
{

    /**
     * Static method to calculate and render the site's tag cloud.
     *
     * @param  int|string $sid
     * @return string
     */
    public static function render($sid)
    {

        $site_tags = '';
        $steTagOutput = '';
        $steTagAry = array();

        $tags = new Phire_Table_Tags();
        $tags->findAll('tag ASC', 'site_id', $sid);

        if (isset($tags->rows[0])) {

            $totalTags = count($tags->rows);

            // Get any tagged pages and track the frequency of the tag.
            foreach ($tags->rows as $tag) {
                $pg = new Phire_Table_Pages();
                $pg->search(array('page_tags' => '%' . $tag->tag_id . '%'));
                $steTagAry[] = array('tag_id' => $tag->tag_id,
                                     'tag' => $tag->tag,
                                     'count' => count($pg->rows));
            }

            // Format the tag weight based on frequency.
            foreach ($steTagAry as $steTag) {
                $percentage = round(($steTag['count'] / $totalTags) * 100);

                if ($percentage == 0) {
                    $fontSize = '0.6';
                } else if ($percentage <= 20) {
                    $fontSize = '0.8';
                } else if (($percentage > 20) && ($percentage <= 40)) {
                    $fontSize = '1.0';
                } else if (($percentage > 40) && ($percentage <= 60)) {
                    $fontSize = '1.2';
                } else if (($percentage > 60) && ($percentage <= 80)) {
                    $fontSize = '1.4';
                } else if ($percentage > 80) {
                    $fontSize = '1.6';
                }

                $steTagOutput .= "    <li><a style=\"font-size: {$fontSize}em;\" class=\"tagCloudLink\" href=\"" . BASE_PATH . "/tag/{$steTag['tag']}\">{$steTag['tag']}</a></li>\n";
            }

            $site_tags = "<ul id=\"tagCloud\">\n" . $steTagOutput . "</ul>\n";

        } else {
            $site_tags = '';
        }

        return $site_tags;

    }

}
