<?php

/**
 * Phire Dashboard
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1
 */

require_once dirname(__FILE__) . '/config.check.php';

try {

    // Get user's allowed sites.
    if (isset($sess->sites)) {

        $site_ids = array();
        foreach ($sess->sites as $value) {
            $site_ids[] = "site_id = '" . $value . "'";
        }

        // Retrieve recent pages.
        $pages = new Phire_Table_Pages();
        $pages->execute("SELECT * FROM " . DB_PREFIX . "pages WHERE (" . implode(' OR ', $site_ids) . ") ORDER BY created DESC LIMIT 9");

    } else {

        $sess->sites = array();
        $site_ids = array();
        $pages = new Phire_Table_Pages();

    }

    $recent = $lang->__('Recent Content');

    // Print the recent content table header.
    print <<<TABLEHEADER
        <table id="dashTable" cellspacing="0" cellpadding="0">
            <tr><td colspan="4" class="grayHeader" style="padding: 0 0 0 7px;"><a class="grayLink" style="font-size: 1.0em;" href="./content/pages.php">{$recent}</a></td></tr>

TABLEHEADER;

    // If pages were found, format and output them.
    if (isset($pages->rows[0])) {

        foreach ($pages->rows as $page) {
            $site = new Phire_Table_Sites();
            $site->findById($page->site_id);

            $page_title = Moc10_String::setString($page->page_title);
            $page_url = (stripos($page->page_url, 'http://') !== false) ? $page->page_url : 'http://' . $site->site_domain . BASE_PATH . $page->page_url;

            if ($page->user_id != 0) {

                if (($sess->access != 'Admin') && ($sess->open_authoring[$page->site_id] == 'Off') && ($sess->user_id != $page->user_id)) {
                    $page_link_title = $page_title;

                } else {
                    $page_link_title = "<a href=\"./content/edit-page.php?pid={$page->page_id}\">{$page_title}</a>";
                }

            } else {
                $name = 'N/A';
                $page_link_title = "<a href=\"./content/edit-page.php?pid={$page->page_id}\">{$page_title}</a>";
            }

            if ($page->published == 'Yes') {
                $status = $lang->__('Published');
                $cls = 'green';
            } else {
                $status = $lang->__('Offline');
                $cls = 'error';
            }

            print("            <tr><td>{$page_link_title}</td><td><a class=\"smallLink\" style=\"font-size: 1.0em;\" href=\"{$page_url}\" target=\"_blank\">{$page_url}</a></td><td style=\"text-align: center;\">" . date('M j, Y', strtotime($page->created)) . "</td><td style=\"text-align: center;\"><span class=\"{$cls}\">{$status}</span></td></tr>\n");
        }
    // Else, print a no results message.
    } else {
        print("            <tr><td colspan=\"4\" style=\"padding: 25px 0 25px 7px;\">There is no recent content.</td></tr>\n");
    }

    // Retrieve and output any recent comments.
    $cmts = new Phire_Table_Comments();
    if (count($site_ids) > 0) {
        $cmts->execute("SELECT * FROM " . DB_PREFIX . "comments LEFT JOIN " . DB_PREFIX . "pages ON " . DB_PREFIX . "comments.page_id = " . DB_PREFIX . "pages.page_id WHERE (" . implode(' OR ', $site_ids) . ") ORDER BY comment_posted DESC LIMIT 5");
    }

    print("            <tr><td colspan=\"4\" style=\"padding: 5px 0 5px 7px; background-color: #ddd;\"><a class=\"grayLink\" style=\"font-size: 1.0em;\" href=\"./content/comments.php\">" . $lang->__('Comments') . "</a></td></tr>\n");

    // If comments were found, format and output them.
    if (isset($cmts->rows[0])) {

        foreach ($cmts->rows as $cmt) {

            $comment_author = Moc10_String::setString($cmt->comment_author)->strip()->html();
            $comment_content = Moc10_String::setString($cmt->comment_content)->sub(0, 75)->strip()->html();
            $comment_posted = Moc10_String::setString($cmt->comment_posted)->date('M j, Y');

            $page = new Phire_Table_Pages();
            $page->join(DB_PREFIX . 'sites', 'site_id', null, 'page_id', $cmt->page_id, 1);

            print("            <tr><td><a href=\"./content/edit-comment.php?cid={$cmt->comment_id}\">{$comment_content}...</a></td><td>{$page->rows[0]['site_domain']}" . BASE_PATH . "{$page->rows[0]['page_url']}</td><td style=\"text-align: center;\">{$comment_posted}</td><td style=\"text-align: center;\">{$comment_author}</td></tr>\n");

        }
    // Else, print a no results message.
    } else {
        print("            <tr><td colspan=\"4\" style=\"padding: 25px 0 25px 7px;\">" . $lang->__('There are no recent comments.') . "</td></tr>\n");
    }

    if (($sess->access == 'Basic') || ($sess->access == 'Full') || ($sess->access == 'Admin')) {

        // Retrieve and output any recent themes.
        $themes = new Phire_Table_Themes();
        if (count($site_ids) > 0) {
            $themes->execute("SELECT * FROM " . DB_PREFIX . "themes WHERE (" . implode(' OR ', $site_ids) . ") LIMIT 3");
        }

        print("            <tr><td colspan=\"4\" style=\"padding: 5px 0 5px 7px; background-color: #ddd;\"><a class=\"grayLink\" style=\"font-size: 1.0em;\" href=\"./extensions/themes.php\">" . $lang->__('Themes') . "</a></td></tr>\n");

        // If themes were found, format and output them.
        if (isset($themes->rows[0])) {

            foreach ($themes->rows as $theme) {

                $theme_name = Moc10_String::setString($theme->theme_name)->strip()->html();

                $site = new Phire_Table_Sites();
                $site->findById($theme->site_id);

                print("            <tr><td style=\"text-align: left;\"><strong>{$theme_name}</strong></td><td>{$site->site_domain}</td><td style=\"text-align: center;\">v{$theme->theme_version}</td><td style=\"text-align: center;\">{$theme->theme_author}</td></tr>\n");

            }
        // Else, print a no results message.
        } else {
            print("            <tr><td colspan=\"4\" style=\"padding: 25px 0 25px 7px;\">" . $lang->__('There are no recent themes.') . "</td></tr>\n");
        }

        // Retrieve and output any recent plugins.
        $plugins = new Phire_Table_Plugins();
        if (count($site_ids) > 0) {
            $plugins->execute("SELECT * FROM " . DB_PREFIX . "plugins WHERE (" . implode(' OR ', $site_ids) . ") LIMIT 3");
        }

        print("            <tr><td colspan=\"4\" style=\"padding: 5px 0 5px 7px; background-color: #ddd;\"><a class=\"grayLink\" style=\"font-size: 1.0em;\" href=\"./extensions/plugins.php\">" . $lang->__('Plugins') . "</a></td></tr>\n");

        // If plugins were found, format and output them.
        if (isset($plugins->rows[0])) {

            foreach ($plugins->rows as $plugin) {

                $plugin_name = Moc10_String::setString($plugin->plugin_name)->strip()->html();

                $site = new Phire_Table_Sites();
                $site->findById($plugin->site_id);

                print("            <tr><td style=\"text-align: left;\"><a href=\"" . BASE_PATH . CONTENT_PATH . "/extensions/plugins/{$plugin->plugin_folder}/?sys_path=" . BASE_PATH . SYS_PATH . "\">{$plugin_name}</a></td><td>{$site->site_domain}</td><td style=\"text-align: center;\">v{$plugin->plugin_version}</td><td style=\"text-align: center;\">{$plugin->plugin_author}</td></tr>\n");

            }
        // Else, print a no results message.
        } else {
            print("            <tr><td colspan=\"4\" style=\"padding: 25px 0 25px 7px;\">" . $lang->__('There are no recent plugins.') . "</td></tr>\n");
        }
    }

    // Finalize the recent content table.
    print("        </table>\n");

    $system = $lang->__('System Overview');

    // Print the system and site overview table header.
    print <<<TABLEHEADER
        <table id="overviewTable" cellspacing="0" cellpadding="0">
            <tr><td colspan="2" class="grayHeader" style="padding: 0 0 0 7px;"><strong>{$system}</strong></td></tr>

TABLEHEADER;

    // Retrieve and output current system and user stats.
    $config = new Phire_Table_Config();

    $users = new Phire_Table_Users();
    $users->findAll();

    $sessions = new Phire_Table_Sessions();
    $sessions->findAll();

    $updateMsg = (isset($sess->update_version) && ($sess->access == 'Admin')) ? "<br />(<a href=\"./system/update.php\">" . $lang->__('Update to') . " v " . $sess->update_version . "</a>?)" : '';

    print("            <tr><td><strong>" . $lang->__('System Version:') . "</strong></td><td>" . $config->settings['system_version'] . $updateMsg . "</td></tr>\n");
    print("            <tr><td><strong>" . $lang->__('Operating System:') . "</strong></td><td>" . $config->settings['server_os'] . "</td></tr>\n");
    print("            <tr><td><strong>" . $lang->__('Server Software:') . "</strong></td><td>" . ((stripos($config->settings['server_software'], 'iis') !== false) ? 'IIS' : 'Apache') . "</td></tr>\n");
    print("            <tr><td><strong>" . $lang->__('MySQL Version:') . "</strong></td><td>" . $config->settings['mysql_version'] . "</td></tr>\n");
    print("            <tr><td><strong>" . $lang->__('PHP Version:') . "</strong></td><td>" . $config->settings['php_version'] . "</td></tr>\n");
    print("            <tr><td><strong>" . $lang->__('Number of Users:') . "</strong></td><td>" . count($users->rows) . "</td></tr>\n");
    print("            <tr><td><strong>" . $lang->__('Current Sessions:') . "</strong></td><td>" . count($sessions->rows) . "</td></tr>\n");
    print("            <tr><td><strong>" . $lang->__('Installed On:') . "</strong></td><td>" . date('M j, Y', strtotime($config->settings['installed_on'])) . "</td></tr>\n");
    print("            <tr><td><strong>" . $lang->__('Updated On:') . "</strong></td><td>" . (($config->settings['updated_on'] == '0000-00-00 00:00:00') ? $lang->__('Never') : date('M j, Y', strtotime($config->settings['updated_on']))) . "</td></tr>\n");
    print("            <tr><td colspan=\"2\" style=\"padding: 5px 0 5px 7px; background-color: #ddd;\"><strong>" . $lang->__('Sites') . "</strong></td></tr>\n");

    // Retrieve and output the stats of any allowed sites.
    $sites = new Phire_Table_Sites();
    $sites->findAll();

    foreach ($sites->rows as $site) {
        if (in_array($site->site_id, $sess->sites)) {
            $pages = new Phire_Table_Pages();
            $pages->findAll(null, 'site_id', $site->site_id);
            $members = new Phire_Table_Members();
            $num_of_members = $members->getCount($site->site_id);
            $pg_reqs = 0;
            if (isset($pages->rows[0])) {
                foreach ($pages->rows as $page) {
                    $pg_reqs += $page->page_requests;
                }
            }
            if ($site->site_live == 'Yes') {
                $status = $lang->__('Live');
                $cls = 'green';
                $bgcolor = '#d4ebc6';
            } else {
                $status = $lang->__('Offline');
                $cls = 'error';
                $bgcolor = '#ebc6c6';
            }
            print("            <tr><td style=\"width: 60%; background-color: {$bgcolor};\"><strong class=\"{$cls}\">" . $site->site_domain . "</strong></td><td style=\"width: 40%; background-color: {$bgcolor};\"><span class=\"{$cls}\">{$status}</span></td></tr>\n");
            print("            <tr><td><strong>" . $lang->__('Total Pages:') . "</strong></td><td>" . count($pages->rows) . "</td></tr>\n");
            print("            <tr><td><strong>" . $lang->__('Total Page Requests:') . "</strong></td><td>" . $pg_reqs . "</td></tr>\n");
            print("            <tr><td><strong>" . $lang->__('Total 404 Requests:') . "</strong></td><td>" . $sites->get404s($site->site_id) . "</td></tr>\n");
            print("            <tr><td><strong>" . $lang->__('Total Members:') . "</strong></td><td>" . $num_of_members . "</td></tr>\n");
        }
    }

    // Finalize the system and site overview table.
    print("        </table>\n");

// Else throw a exception/error.
} catch (Exception $e) {

    print("        <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 10px 0;\">" . $e->getMessage() . "</p>\n");

}

?>
