<?php

/**
 * Phire Edit File
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

set_time_limit(0);
require_once '../../bootstrap.php';

try {

    // Retrieve session and check if the edit file action has been cancelled, clearing out any related session data.
    $sess = Moc10_Session::getInstance();

    if ((isset($_GET['action'])) && ($_GET['action'] == 'cancel')) {

        unset($sess->file_error);
        unset($sess->edit_file_form);

        if (isset($_GET['plugin'])) {
            header('Location: ' . BASE_PATH . CONTENT_PATH . '/extensions/plugins/' . $_GET['plugin'] . '/?sys_path=' . BASE_PATH . SYS_PATH);
        } else {
            header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_GET['mobile'])) ? 'mobile/' : '') . 'assets/files.php');
        }

    // Else, get the POST data and validate the form.
    } else {

        unset($sess->edit_file_form);
        unset($sess->file_error);

        $fle_nme = (isset($_FILES['file_name']['name']) ? $_FILES['file_name']['name'] : null);

        $form = new Phire_Form_EditFile(BASE_PATH . SYS_PATH . '/core/process/edit.file.php?fid=' . $_POST['file_id'], 'post', '        ');
        $form->init($_POST, $fle_nme);

        // If the form is valid, process the file.
        if ($form->isValid()) {

            $fle = new Phire_Table_Files();
            $fle->findById($_POST['file_id']);

            $old_site = new Phire_Table_Sites();
            $old_site->findById($fle->site_id);

            $new_site = new Phire_Table_Sites();
            $new_site->findById($_POST['site_id']);

            if ($_FILES['file_name']['name'] != '') {
                $path_parts = pathinfo($_FILES['file_name']['name']);

                // Check the site for any file format restrictions.
                if ($new_site->allowed_file_formats != 'any') {
                    $allowed_types = explode('|', $new_site->allowed_file_formats);
                    if (!isset($path_parts['extension']) || !in_array(strtolower($path_parts['extension']), $allowed_types)) {
                        $sess->file_error = (!isset($path_parts['extension'])) ? "<div class=\"error\">" . $lang->__('There was no defined extension for that file.') . "</div>\n" : "<div class=\"error\">" . $lang->__('The %1 file format is not allowed.', strtoupper($path_parts['extension'])) . "</div>\n";
                    }
                }

            }

            // If a file is passed that isn't allowed, return with the error.
            if (isset($sess->file_error)) {
                $sess->edit_file_form = $form;
                header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_POST['mobile'])) ? 'mobile/' : '') . 'assets/edit-file.php?fid=' . $_POST['file_id']);
            // Else, finish processing the file.
            } else {
                unset($sess->edit_file_form);
                unset($sess->file_error);

                // Check the file size against the max allowed file size.
                $file_max_size = null;

                if (strpos($new_site->file_max_size, 'MB') !== false) {
                    $file_max_size = str_replace(' MB', '000000', $new_site->file_max_size);
                } else {
                    $file_max_size = str_replace(' KB', '000', $new_site->file_max_size);
                }

                if ($_FILES['file_name']['name'] != '') {

                    // Delete the old file.
                    if (file_exists($new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/files/' . $_POST['current_file_name'])) {
                        unlink($new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/files/' . $_POST['current_file_name']);
                    }

                    // Check for duplicate files and rename accordingly.
                    $newfile = $_FILES['file_name']['name'];
                    $path_parts = pathinfo($newfile);
                    $orgfile = $path_parts['filename'];
                    $ext = (isset($path_parts['extension'])) ? $path_parts['extension'] : 'NO_EXT';
                    $i = 1;

                    while (file_exists($new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/files/' . $newfile)) {
                        $newfile = $orgfile . '_' . $i . '.' . $ext;
                        $i++;
                    }

                    // Move file to the new site if applicable.
                    if (($ext != 'NO_EXT') && ($fle->site_id != $_POST['site_id'])) {
                        $fl = new Moc10_File($old_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/files/' . $fle->file_name);
                        $fl->move($new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/files/' . $newfile);
                    }

                    // Process the new file upload.
                    if ($ext != 'NO_EXT') {
                        $file = new Moc10_File_Upload($_FILES['file_name']['tmp_name'], $new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/files/' . $newfile, $file_max_size);
                        $fle->file_name = $newfile;
                        unset($sess->file_error);
                    } else {
                        $sess->file_error = "<div class=\"error\">" . $lang->__('That file format is not allowed.') . "</div>\n";
                    }

                } else {
                    // Check for duplicate files and rename accordingly.
                    $newfile = $fle->file_name;
                    // Move file to the new site if applicable.
                    if ($fle->site_id != $_POST['site_id']) {
                        $path_parts = pathinfo($newfile);
                        $orgfile = $path_parts['filename'];
                        $ext = (isset($path_parts['extension'])) ? $path_parts['extension'] : 'NO_EXT';
                        $i = 1;

                        while (file_exists($new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/files/' . $newfile)) {
                            $newfile = $orgfile . '_' . $i . '.' . $ext;
                            $i++;
                        }
                        if ($ext != 'NO_EXT') {
                            $fl = new Moc10_File($old_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/files/' . $fle->file_name);
                            $fl->move($new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/files/' . $newfile);
                            unset($sess->file_error);
                        } else {
                            $sess->file_error = "<div class=\"error\">" . $lang->__('That file format is not allowed.') . "</div>\n";
                        }

                    }
                    $fle->file_name = $newfile;
                }

                if (isset($sess->file_error)) {
                    $sess->edit_file_form = $form;
                    header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_POST['mobile'])) ? 'mobile/' : '') . 'assets/edit-file.php?fid=' . $_POST['file_id']);
                } else {

                    // Edit the file in the system.
                    $fle->site_id = $_POST['site_id'];
                    $fle->user_id = ($fle->user_id == 0) ? $sess->user_id : $fle->user_id;
                    $fle->section_id = $_POST['section_id'];
                    $fle->file_title = (($_POST['file_title'] != '') ? $_POST['file_title'] : $fle->file_name);
                    $fle->file_desc = (($_POST['file_desc'] != '') ? $_POST['file_desc'] : '');
                    $fle->file_updated = date('Y-m-d H:i:s');
                    $fle->save();

                    // Return.
                    if ((isset($_POST['plugin'])) && (!is_null($_POST['plugin']))) {
                        header('Location: ' . BASE_PATH . CONTENT_PATH . '/extensions/plugins/' . $_POST['plugin'] .'/?action=saved&sys_path=' . BASE_PATH . SYS_PATH);
                    } else {
                        header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_POST['mobile'])) ? 'mobile/' : '') . 'assets/files.php?action=saved');
                    }

                }

            }

        // Else, set the form into a session variable and return.
        } else {

            $sess->edit_file_form = $form;
            header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_POST['mobile'])) ? 'mobile/' : '') . 'assets/edit-file.php?fid=' . $_POST['file_id']);

        }

    }

// Else throw a exception/error.
} catch (Exception $e) {

    include_once 'init.php';
    include_once '../includes/error.header.php';
    print("        <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 0 0;\">" . $e->getMessage() . "</p>\n");
    include_once '../includes/footer.php';

}

?>
