<?php

/**
 * Phire Session Check
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

require_once dirname(__FILE__) . '/config.check.php';

$sess = Moc10_Session::getInstance();
$mob = new Moc10_Session_Mobile(BASE_PATH . SYS_PATH . '/mobile/', BASE_PATH . SYS_PATH . '/');
$config = new Phire_Table_Config();

// If an SSL connection is required, but not set, force it.
if (($config->settings['use_ssl_connection'] == 'Yes') && ($_SERVER['SERVER_PORT'] == 80)) {

    header('Location: https://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI']);

// If a mobile device is detected, bounce to the mobile login page.
} else if ($mob->isMobile !== false) {

    $mob->goToMobile();

// If a session id is not found, bounce the user to the login page.
} else if (!isset($sess->user_sess_id)) {

    $sess->attempted_url = $_SERVER['REQUEST_URI'];
    header('Location: ' . BASE_PATH . SYS_PATH . '/login.php');

// Else, check if the session still exists in the DB, or hasn't expired.
} else {

    $existing_user_sess = new Phire_Table_Sessions();
    $existing_user_sess->findById($sess->user_sess_id);

    // If the session does not exist, bounce the user.
    if (!isset($existing_user_sess->session_id)) {

        $sess->expire_msg = "        <div class=\"error\" style=\"padding: 20px 0 0 20px;\">" . $lang->__('Your session has either been terminated or has expired.') . "</div>\n";
        header('Location: ' . BASE_PATH . SYS_PATH . '/login.php');

    // If the session has expired, bounce the user.
    } else if ((time() - strtotime($existing_user_sess->session_last_action)) > 1800) {

        unset($sess->user_sess_id);
        $existing_user_sess->delete();
        $sess->expire_last_url = $_SERVER['REQUEST_URI'];
        $sess->expire_msg = "        <div class=\"error\" style=\"padding: 20px 0 0 20px;\">" . $lang->__('Your session has expired.') . "</div>\n";
        header('Location: ' . BASE_PATH . SYS_PATH . '/login.php');

    // Else, update the session.
    } else {

        $existing_user_sess->session_last_action = date('Y-m-d H:i:s');
        $existing_user_sess->save();

    }

}

?>