<?php

/**
 * Phire Version Check
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

require_once dirname(__FILE__) . '/config.check.php';

$sess = Moc10_Session::getInstance();
$system = new Phire_Table_Config();
$avail = false;
$new_ver = null;
$url = 'http://www.phirecms.org/updates/feed.php?v=1.1.2';

try {

    // Load and parse the version feed.
    if (($xml =@ new SimpleXMLElement($url, LIBXML_NOWARNING, true)) !== false) {

        // If updates are found, check the versions against the current system version.
        if (count($xml->update) > 0) {

            $versions = array();

            foreach ($xml->update as $upd) {
                $versions[] = (string)$upd->attributes()->version;
            }

            if (isset($versions[0])) {
                foreach ($versions as $ver) {
                    if (!$avail) {
                        if ($ver > $system->settings['system_version']) {
                            $new_ver = $ver;
                            $avail = true;
                        }
                    }
                }
            }

        }

        // If the next, newest version is found, set the session variable and system messaging accordingly.
        if ($avail) {
            $sess->update_version = $new_ver;
            $sess->update_msg = "        " . $lang->__('An update to %1 is available. Please %2click here%3 to update your system.', array("<strong>v {$sess->update_version}</strong>", "<a href=\"" . BASE_PATH . SYS_PATH . "/system/update.php\">", "</a>")) . "<br />\n";
        } else {
            unset($sess->update_version);
            unset($sess->update_msg);
        }

    }

} catch (Exception $e) {
    unset($sess->update_version);
    unset($sess->update_msg);
}

?>